## [What ways are there to show two analytical methods are equivalent ?](http://stats.stackexchange.com/questions/527/what-ways-are-there-to-show-two-analytical-methods-are-equivalent)

The simple correlation approach isn't the right way to analyze results from method comparison studies. There are (at least) two highly recommended books on this topic that I referenced at the end (1,2). Briefly stated, when comparing measurement methods we usually expect that (a) our conclusions should not depend on the particular sample used for the comparison, and (b) measurement error associated to the particular measurement instrument should be accounted for. This precludes any method based on correlations, and we shall turn our attention to variance components or mixed-effects models that allow to reflect the systematic effect of item (here, item stands for individual or sample on which data are collected), which results from (a).

In your case, you have single measurements collected using two different methods (I assume that none of them might be considered as a gold standard) and the very basic thing to do is to plot the differences ($X_1-X_2$) versus the means ($(X_1+X_2)/2$); this is called a [Bland-Altman plot][1]. It will allow you to check if (1) the variations between the two set of measurements are constant and (2) the variance of the difference is constant across the range of observed values. Basically, this is just a 45° rotation of a simple scatterplot of $X_1$ vs. $X_2$, and its interpretation is close to a plot of fitted *vs.* residuals values used in linear regression. Then,

* if the difference is constant (*constant bias*), you can compute the limit of agreement (see (3))
* if the difference is not constant across the range of measurement, you can fit a linear regression model between the two methods (choose the one you want as predictor)
* if the variance of the differences is not constant, try to find a suitable transformation that makes the relationship linear with constant variance

Other details may be found in (2), chapter 4.

**References**

 1. Dunn, G (2004). *Design and Analysis of Reliability Studies*. Arnold. See the review in the [*International Journal of Epidemiology*][2].
 2. Carstensen, B (2010). *Comparing clinical measurement methods*. Wiley. See the [companion website][3], including R code.
 3. The original article from Bland and Altman, [Statistical methods for assessing agreement between two methods of clinical measurement][4].
 4. Carstensen, B (2004). [Comparing and predicting between several methods of measurement][5]. *Biostatistics*, *5(3)*, 399–413.


  [1]: http://en.wikipedia.org/wiki/Bland–Altman_plot
  [2]: http://ije.oxfordjournals.org/content/34/2/499.1.full
  [3]: http://staff.pubhealth.ku.dk/~bxc/MethComp/
  [4]: http://www-users.york.ac.uk/~mb55/meas/ba.htm
  [5]: http://biostatistics.oxfordjournals.org/content/5/3/399.full.pdf
