## [Is adjusting p-values in a multiple regression for multiple comparisons a good idea?](http://stats.stackexchange.com/questions/3200/is-adjusting-p-values-in-a-multiple-regression-for-multiple-comparisons-a-good-id)

It seems your question more generally addresses the problem of identifying good predictors. In this case, you should consider using some kind of penalized regression (methods dealing with variable or [feature selection][1] are relevant too), with e.g. L1, L2 (or a combination thereof, the so-called [elasticnet][2]) penalties (look for related questions on this site, or the R [penalized][3] and [elasticnet][4] package, among others). 

Now, about correcting p-values for your regression coefficients (or equivalently your partial correlation coefficients) to protect against over-optimism (e.g. with Bonferroni or, better, step-down methods), it seems this would only be relevant if you are considering one model and seek those predictors that contribute a significant part of explained variance, that is if you don't perform model selection (with stepwise selection, or hierarchical testing). This article may be a good start: [Bonferroni Adjustments in Tests for Regression Coefficients][5]. Be aware that such correction won't protect you against multicolinearity issue, which affects the reported p-values. 

Given your data, I would recommend using some kind of iterative model selection techniques. In R for instance, the `stepAIC` function allows to perform stepwise model selection by exact AIC. You can also estimate the relative importance of your predictors based on their contribution to $R^2$ using boostrap (see the [relaimpo][6] package). I think that reporting effect size measure or % of explained variance are more informative than p-value, especially in a confirmatory model.

It should be noted that stepwise approaches have also their drawbacks (e.g., Wald tests are not adapted to conditional hypothesis as induced by the stepwise procedure), or as indicated by Frank Harrell on [R mailing][7], "stepwise variable selection based on AIC has all the problems of stepwise variable selection based on P-values. AIC is just a restatement of the P-Value" (but AIC remains useful if the set of predictors is already defined); a related question -- [Is a variable significant in a linear regression model?][8] -- raised interesting comments ([@Rob][9], among others) about the use of AIC for variable selection. I append a couple of references at the end (including papers kindly provided by [@Stephan][10]); there is also a lot of other references on [P.Mean][11]. 

Frank Harrell authored a book on [Regression Modeling Strategy][12] which includes a lot of discussion and advices around this problem (§4.3, pp. 56-60). He also developed efficient R routines to deal with generalized linear models (See the [Design][13] or [rms][14] packages). So, I think you definitely have to take a look at it (his [handouts][15] are available on his homepage).

**References**

1. Whittingham, MJ, Stephens, P, Bradbury, RB,  and Freckleton, RP (2006). [Why do we still use stepwise modelling in ecology and behaviour?][16] *Journal of Animal Ecology*, *75*, 1182-1189.
2. Austin, PC (2008). [Bootstrap model selection had similar performance for selecting authentic and noise variables compared to backward variable elimination: a simulation study][17]. *Journal of Clinical Epidemiology*, *61(10)*, 1009-1017.
3. Austin, PC and Tu, JV (2004). [Automated variable selection methods for logistic regression produced unstable models for predicting acute myocardial infarction mortality][18]. *Journal of Clinical Epidemiology*, *57*, 1138–1146.
4. Greenland, S (1994). [Hierarchical regression for epidemiologic analyses of multiple exposures][19]. *Environmental Health Perspectives*, *102(Suppl 8)*, 33–39.
5. Greenland, S (2008). [Multiple comparisons and association selection in general epidemiology][20]. *International Journal of Epidemiology*, *37(3)*, 430-434.
6. Beyene, J, Atenafu, EG, Hamid, JS, To, T, and Sung L (2009). [Determining relative importance of variables in developing and validating predictive models][21]. *BMC Medical Research Methodology*, *9*, 64.
7. Bursac, Z, Gauss, CH, Williams, DK, and Hosmer, DW (2008). [Purposeful selection of variables in logistic regression][22]. *Source Code for Biology and Medicine*, *3*, 17.
8. Brombin, C, Finos, L, and Salmaso, L (2007). [Adjusting stepwise p-values in generalized linear models][23]. *International Conference on Multiple Comparison Procedures*. -- see `step.adj()` in the R [someMTP][24] package.
9. Wiegand, RE (2010). [Performance of using multiple stepwise algorithms for variable selection][25]. *Statistics in Medicine*, 29(15), 1647–1659.
10. Moons KG, Donders AR, Steyerberg EW, and Harrell FE (2004). Penalized Maximum Likelihood Estimation to predict binary outcomes. *Journal of Clinical Epidemiology*, *57(12)*, 1262–1270.
11. Tibshirani, R (1996). [Regression shrinkage and selection via the lasso][26]. *Journal of The Royal Statistical Society B*, *58(1)*, 267–288.
12. Efron, B, Hastie, T, Johnstone, I, and Tibshirani, R (2004). [Least Angle Regression][27]. *Annals of Statistics*, *32(2)*, 407-499.
13. Flom, PL and Cassell, DL (2007). [Stopping Stepwise: Why stepwise and similar selection methods are bad, and what you should use][28]. *NESUG 2007 Proceedings*.
14. Shtatland, E.S., Cain, E., and Barton, M.B. (2001). [The perils of stepwise logistic regression and how to escape them using information criteria and the Output Delivery System][29]. *SUGI 26 Proceedings* (pp. 222–226).


  [1]: http://www.google.fr/url?sa=t&source=web&cd=1&ved=0CBgQFjAA&url=http%3A%2F%2Fen.wikipedia.org%2Fwiki%2FFeature_selection&ei=w5qkTLHOA8iK4gbr0MH9DA&usg=AFQjCNFGSoQruvgm6fTvAtx8NUU3MDBBcw&sig2=4wcurlN8irzgYgr3chlopA
  [2]: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.124.4696&rep=rep1&type=pdf
  [3]: http://cran.r-project.org/web/packages/penalized/index.html
  [4]: http://cran.r-project.org/package=elasticnet
  [5]: http://mlrv.ua.edu/2006/Mundfrom-etal-MLRV-3.pdf
  [6]: http://cran.r-project.org/web/packages/relaimpo/index.html
  [7]: http://www.mail-archive.com/r-help@r-project.org/msg105680.html
  [8]: http://stats.stackexchange.com/questions/1016/is-a-variable-significant-in-a-linear-regression-model
  [9]: http://stats.stackexchange.com/users/159/rob-hyndman
  [10]: http://stats.stackexchange.com/users/1352/stephan-kolassa
  [11]: http://www.pmean.com/category/MultipleComparisons.html
  [12]: http://biostat.mc.vanderbilt.edu/twiki/bin/view/Main/RmS
  [13]: http://cran.r-project.org/web/packages/Design/index.html
  [14]: http://cran.r-project.org/web/packages/rms/index.html
  [15]: http://biostat.mc.vanderbilt.edu/wiki/pub/Main/RmS/course2.pdf
  [16]: http://www.ncl.ac.uk/biology/assets/MWhitt_pdf/06j_animal.pdf
  [17]: http://www.ncbi.nlm.nih.gov/pubmed/18539429?ordinalpos=1
  [18]: http://uncwddas.googlecode.com/files/article2.pdf
  [19]: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC1566551/
  [20]: http://ije.oxfordjournals.org/content/37/3/430.full
  [21]: http://www.biomedcentral.com/1471-2288/9/64/
  [22]: http://www.scfbm.org/content/3/1/17
  [23]: http://www.mcp-conference.org/2007/presentations/Brombin_Chiara.pdf
  [24]: http://cran.r-project.org/web/packages/someMTP/index.html
  [25]: http://onlinelibrary.wiley.com/doi/10.1002/sim.3943/abstract
  [26]: http://www-stat.stanford.edu/~tibs/lasso/lasso.pdf
  [27]: http://www-stat.stanford.edu/~hastie/Papers/LARS/LeastAngle_2002.pdf
  [28]: http://www.nesug.org/Proceedings/nesug07/sa/sa07.pdf
  [29]: http://www2.sas.com/proceedings/sugi26/p222-26.pdf
