## [From a statistical perspective, can one infer causality using propensity scores with an observational study?](http://stats.stackexchange.com/questions/3400/from-a-statistical-perspective-can-one-infer-causality-using-propensity-scores-w)

At the beginning of an article aiming at promoting the use of PSs in epidemiology, Oakes and Church (1) cited Hernán and Robins's claims about confounding effect in epidemiology (2):

> Can you guarantee that the results
> from your observational study are
> unaffected by unmeasured confounding?
> The only answer an epidemiologist can
> provide is ‘no’.

This is not just to say that we cannot ensure that results from observational studies are unbiased or useless (because, as @propofol said, their results can be useful for designing RCTs), but also that PSs do certainly not offer a complete solution to this problem, or at least do not necessarily yield better results than other matching or multivariate methods (see e.g. (10)).

Propensity scores (PS) are, by construction, *probabilistic* not *causal* indicators. The choice of the covariates that enter the propensity score function is a key element for ensuring its reliability, and their weakness, as has been said, mainly stands from not controlling for unobserved confounders (which is quite likely in retrospective or [case-control][1] studies). Others factors have to be considered: (a) model misspecification will impact direct effect estimates (not really more than in the OLS case, though), (b) there may be missing data at the level of the covariates, (c) PSs do not overcome synergistic effects which are know to affect causal interpretation (8,9).

As for references, I found Roger Newson's slides -- [Causality, confounders, and propensity scores][2] -- relatively well-balanced about the pros and cons of using propensity scores, with illustrations from real studies.
There were also several good papers discussing the use of propensity scores in observational studies or environmental epidemiology two years ago in *Statistics in Medicine*, and I enclose a couple of them at the end (3-6). But I like Pearl's review (7) because it offers a larger perspective on causality issues (PSs are discussed p. 117 and 130). Obviously, you will find many more illustrations by looking at applied research. I would like to add two recent articles from William R Shadish that came across Andrew Gelman's website (11,12). The use of propensity scores is discussed, but the two papers more largely focus on causal inference in observational studies (and how it compare to randomized settings).

**References**

1. Oakes, J.M. and Church, T.R. (2007). [Invited Commentary: Advancing Propensity Score Methods in Epidemiology][3]. *American Journal of Epidemiology*, 165(10), 1119-1121.
2. Hernan M.A. and Robins J.M. (2006). [Instruments for causal inference: an epidemiologist's dream?][4] *Epidemiology*, 17, 360-72.
3. Rubin, D. (2007). [The design versus the analysis of observational studies for causal effects: Parallels with the design of randomized trials][5]. *Statistics in Medicine*, 26, 20–36.
4. Shrier, I. (2008). [Letter to the editor][6]. *Statistics in Medicine*, 27, 2740–2741.
5. Pearl, J. (2009). [Remarks on the method of propensity score][7]. *Statistics in Medicine*, 28, 1415–1424.
6. Stuart, E.A. (2008). [Developing practical recommendations for the use of propensity scores: Discussion of ‘A critical appraisal of propensity score matching in the medical literature between 1996 and 2003’ by Peter Austin][8]. *Statistics in Medicine*, 27, 2062–2065. 
7. Pearl, J. (2009). [Causal inference in statistics: An overview][9]. *Statistics Surveys*, 3, 96-146.
8. Oakes, J.M. and Johnson, P.J. (2006). [Propensity score matching for social epidemiology][10]. In *Methods in Social Epidemiology*, J.M. Oakes and S. Kaufman (Eds.), pp. 364-386. Jossez-Bass.
9. Höfler, M (2005). [Causal inference based on counterfactuals][11]. *BMC Medical Research Methodology*, 5, 28.
10. Winkelmayer, W.C. and Kurth, T. (2004). [Propensity scores: help or hype?][12] *Nephrology Dialysis Transplantation*, 19(7), 1671-1673.
11. Shadish, W.R., Clark, M.H., and Steiner, P.M. (2008). [Can Nonrandomized Experiments Yield Accurate Answers? A Randomized Experiment Comparing Random and Nonrandom Assignments][13]. *JASA*, 103(484), 1334-1356.
12. Cook, T.D., Shadish, W.R., and Wong, V.C. (2008). [Three Conditions under Which Experiments and Observational Studies Produce Comparable Causal Estimates: New Findings from Within-Study Comparisons][14]. *Journal of Policy Analysis and Management*, 27(4), 724–750.


  [1]: http://en.wikipedia.org/wiki/Case-control_study
  [2]: http://www.imperial.ac.uk/nhli/r.newson/miscdocs/causconf1.pdf
  [3]: http://aje.oxfordjournals.org/content/165/10/1119.full
  [4]: http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.158.2969
  [5]: http://www.ncbi.nlm.nih.gov/pubmed/17072897
  [6]: http://onlinelibrary.wiley.com/doi/10.1002/sim.3172/abstract
  [7]: ftp://ftp.cs.ucla.edu/pub/stat_ser/r345-sim.pdf
  [8]: http://www.epi.msu.edu/janthony/requests/propensity/Stuart_Commentary_3.pdf
  [9]: http://www.i-journals.org/ss/viewarticle.php?id=57
  [10]: http://www.google.fr/url?sa=t&source=web&cd=18&ved=0CFMQFjAHOAo&url=http%3A%2F%2Fwww.tc.umn.edu%2F~oakes007%2FFiles%2FBook%2FOakes%2520%26%2520Johnson%2520p-score%2520chapter.pdf&ei=iu6uTLSeC8jN4Abz-PH3Bg&usg=AFQjCNEse-1Vh8p9OFKkgLIk1Wq9Mn9b4A&sig2=nhrdB0PA0m3vNlIfKuR6pg
  [11]: http://www.biomedcentral.com/1471-2288/5/28
  [12]: http://ndt.oxfordjournals.org/content/19/7/1671.full
  [13]: http://www.stat.columbia.edu/~cook/movabletype/mlm/shadish1.pdf
  [14]: http://www.stat.columbia.edu/~cook/movabletype/mlm/shadish2.pdf
