## [Inter-rater reliability for ordinal or interval data](http://stats.stackexchange.com/questions/3539/inter-rater-reliability-for-ordinal-or-interval-data)

The Kappa ($\kappa$) statistic is a quality index that compares observed agreement between 2 raters on a nominal or ordinal scale with agreement expected by chance alone (as if raters were tossing up). Extensions for the case of multiple raters exist (2, pp. 284–291). In the case of *ordinal data*, you can use the [weighted][1] $\kappa$, which basically reads as usual $\kappa$ with off-diagonal elements contributing to the measure of agreement. Fleiss (3) provided guidelines to interpret $\kappa$ values but these are merely rules of thumbs.

The $\kappa$ statistic is asymptotically equivalent to the ICC estimated from a two-way random effects ANOVA, but significance tests and SE coming from the usual ANOVA framework are not valid anymore with binary data. It is better to use bootstrap to get confidence interval (CI). Fleiss (8) discussed the connection between weighted kappa and the intraclass correlation (ICC).

It should be noted that some psychometricians don't very much like $\kappa$ because it is affected by the prevalence of the object of measurement much like predictive values are affected by the prevalence of the disease under consideration, and this can lead to paradoxical results.

Inter-rater reliability for $k$ raters can be estimated with Kendall’s coefficient of concordance, $W$. When the number of items or units that are rated $n > 7$, $k(n − 1)W \sim \chi^2(n − 1)$. (2, pp. 269–270). This asymptotic approximation is valid for moderate value of $n$ and $k$ (6), but with less than 20 items $F$ or permutation tests are more suitable (7). There is a close relationship between Spearman’s $\rho$ and Kendall’s $W$ statistic: $W$ can be directly calculated from the mean of the pairwise Spearman correlations (for untied observations only).

[Polychoric][2] (ordinal data) correlation may also be used as a measure of inter-rater agreement. Indeed, they allow to

* estimate what would be the correlation if ratings were made on a continuous scale,
* test marginal homogeneity between raters.

In fact, it can be shown that it is a special case of latent trait modeling, which allows to relax distributional assumptions (4).

About *continuous* (or so assumed) measurements, the ICC which quantifies the proportion of variance attributable to the between-subject variation is fine. Again, bootstraped CIs are recommended. As @ars said, there are basically two versions -- agreement and consistency -- that are applicable in the case of agreement studies (5), and that mainly differ on the way sum of squares are computed; the “consistency” ICC is generally estimated without considering the Item×Rater interaction. The ANOVA framework is useful with specific block design where one wants to minimize the number of ratings ([BIBD][3]) -- in fact, this was one of the original motivation of Fleiss's work. It is also the best way to go for *multiple raters*. The natural extension of this approach is called the [Generalizability Theory][4]. A brief overview is given in [Rater Models: An Introduction][5], otherwise the standard reference is Brennan's book, reviewed in [Psychometrika 2006 71(3)][6].

As for general references, I recommend chapter 3 of *Statistics in Psychiatry*, from Graham Dunn (Hodder Arnold, 2000). For a more complete treatment of reliability studies, the best reference to date is 

> Dunn, G (2004). *Design and Analysis of
> Reliability Studies*. Arnold. See the
> review in the [International Journal
> of Epidemiology][7].

A good online introduction is available on John Uebersax's website, [Intraclass Correlation and Related Methods][8]; it includes a discussion of the pros and cons of the ICC approach, especially with respect to ordinal scales.

Relevant R packages for two-way assessment (ordinal or continuous measurements) are found in the [Psychometrics][9] Task View; I generally use either the [psy][10], [psych][11], or [irr][12] packages. There's also the [concord][13] package but I never used it. For dealing with more than two raters, the [lme4][14] package is the way to go for it allows to easily incorporate random effects, but most of the reliability designs can be analysed using the `aov()` because we only need to estimate variance components.


**References**

1. J Cohen. Weighted kappa: Nominal scale agreement with provision for scales disagreement of partial credit. *Psychological Bulletin*, *70*, 213–220, 1968.
2. S Siegel and Jr N John Castellan. *Nonparametric Statistics for the Behavioral
Sciences*. McGraw-Hill, Second edition, 1988.
3. J L Fleiss. *Statistical Methods for Rates and Proportions*. New York: Wiley, Second
edition, 1981.
4. J S Uebersax. *The tetrachoric and polychoric correlation coefficients*. Statistical Methods for Rater Agreement web site, 2006. Available at: http://john-uebersax.com/stat/tetra.htm. Accessed February 24, 2010.
5. P E Shrout and J L Fleiss. [Intraclass correlation: Uses in assessing rater reliability][15]. *Psychological Bulletin*, *86*, 420–428, 1979.
6. M G Kendall and B Babington Smith. [The problem of m rankings][16]. *Annals of Mathematical Statistics*, *10*, 275–287, 1939.
7. P Legendre. [Coefficient of concordance][17]. In N J Salkind, editor, *Encyclopedia of Research Design*. SAGE Publications, 2010.
8. J L Fleiss. [The equivalence of weighted kappa and the intraclass correlation coefficient as measures of reliability][18]. *Educational and Psychological Measurement*, *33*, 613-619, 1973.


  [1]: http://en.wikipedia.org/wiki/Cohen's_kappa#Weighted_Kappa
  [2]: http://en.wikipedia.org/wiki/Polychoric_correlation
  [3]: http://en.wikipedia.org/wiki/Block_design
  [4]: http://en.wikipedia.org/wiki/Generalizability_theory
  [5]: http://www.google.fr/url?sa=t&source=web&cd=17&ved=0CEAQFjAGOAo&url=http%3A%2F%2Flegacy.samsi.info%2F200910%2Fpsycho%2Fpresentations%2FJohnson_raters.pdf&ei=KXu1TKy3IMv44Aaju7SgDQ&usg=AFQjCNGzJnLQqrpaS8x0MiV2YO79w0SYyg&sig2=YgINb6uPkwAwz8eHgLWxng
  [6]: http://www.springerlink.com/content/vu6216157m666366/
  [7]: http://ije.oxfordjournals.org/content/34/2/499.1.full
  [8]: http://www.john-uebersax.com/stat/icc.htm
  [9]: http://cran.r-project.org/web/views/Psychometrics.html
  [10]: http://cran.r-project.org/web/packages/psy/index.html
  [11]: http://cran.r-project.org/web/packages/psych/index.html
  [12]: http://cran.r-project.org/web/packages/irr/index.html
  [13]: http://cran.r-project.org/web/packages/concord/index.html
  [14]: http://cran.r-project.org/web/packages/lme4/index.html
  [15]: http://www3.uta.edu/faculty/ricard/COED/Shrout%20&%20Fleiss%20(1979)%20Intraclass%20correlations.pdf
  [16]: http://projecteuclid.org/DPubS?service=UI&version=1.0&verb=Display&handle=euclid.aoms/1177732186
  [17]: http://www.bio.umontreal.ca/legendre/reprints/Coefficient_of_concordance.pdf
  [18]: http://www.wpic.pitt.edu/research/biometrics/Publications/Biometrics%20Archives%20PDF/456-Fleiss&Cohen19730001.pdf
