## [Choosing clustering method](http://stats.stackexchange.com/questions/3713/choosing-clustering-method)

There is no definitive answer to your question, as even within the same method the choice of the distance to represent individuals (dis)similarity may yield different result, e.g. when using euclidean vs. squared euclidean in hierarchical clustering. As an other example, for binary data, you can choose the Jaccard index as a measure of similarity and proceed with classical hierarchical clustering; but there are alternative approaches, like the Mona ([Monothetic Analysis][1]) algorithm which only considers one variable at a time, while other hierarchical approaches (e.g. classical HC, Agnes, Diana) use all variables at each step. The k-means approach has been extended in various way, including partitioning around medoids (PAM) or representative objects rather than centroids (Kaufman and Rousseuw, 1990), or fuzzy clustering (Chung and Lee, 1992). For instance, the main difference between the k-means and PAM is that PAM minimizes a sum of dissimilarities rather than a sum of squared euclidean distances; fuzzy clustering allows to consider "partial membership" (we associate to each observation a weight reflecting class membership). And for methods relying on a probabilistic framework, or so-called model-based clustering (or [latent profile analysis][2] for the psychometricians), there is a great package: [Mclust][3]. So definitively, you need to consider how to define the resemblance of individuals as well as the method for linking individuals together (recursive or iterative clustering, strict or fuzzy class membership, unsupervised or semi-supervised approach, etc.).

Usually, to assess cluster stability, it is interesting to compare several algorithm which basically "share" some similarity (e.g. k-means and hierarchical clustering, because euclidean distance work for both). For assessing the concordance between two cluster solutions, some pointers were suggested in response to this question, [Where to cut a dendrogram?][4] (see also the cross-references for other link on this website). If you are using R, you will see that several packages are already available in Task View on Cluster Analysis, and several packages include vignettes that explain specific methods or provide case studies. 

[Cluster Analysis: Basic Concepts and Algorithms][5] provides a good overview of several techniques used in Cluster Analysis.
As for a good recent book with R illustrations, I would recommend chapter 12 of Izenman, *Modern Multivariate Statistical Techniques* (Springer, 2008). A couple of other standard references is given below:

* Cormack, R., 1971. A review of classification. *Journal of the Royal Statistical Society, A* 134, 321–367.
* Everitt, B., 1974. *Cluster analysis*. London: Heinemann Educ. Books.
* Gordon, A., 1987. A review of hierarchical classification. *Journal of the Royal Statistical Society, A* 150, 119–137.
* Gordon, A., 1999. *Classification*, 2nd Edition. Chapman and Hall.
* Kaufman, L., Rousseuw, P., 1990. *Finding Groups in Data: An Introduction to Cluster Analysis*. New York, Wiley.


  [1]: http://stat.ethz.ch/R-manual/R-devel/library/cluster/html/mona.html
  [2]: http://spitswww.uvt.nl/~vermunt/ermss2004f.pdf
  [3]: http://www.stat.washington.edu/mclust/
  [4]: http://stats.stackexchange.com/questions/3685/where-to-cut-a-dendrogram
  [5]: http://www-users.cs.umn.edu/~kumar/dmbook/ch8.pdf
