## [How does one calculate Cohen's d and confidence intervals after logit in Stata?](http://stats.stackexchange.com/questions/3826/how-does-one-calculate-cohens-d-and-confidence-intervals-after-logit-in-stata)

Cohen’s d is not directly available in Stata, and you have to resort on external macros, e.g. [sizefx][1] (`ssc install sizefx`). It works fine if you have to series of values, but I found it less handy when you work with a full data set because there's no possibility to pass options to this command (e.g. `by()`).

Anyway, you can still use the original formula (with pooled SDs), 

$$
\delta_c=\frac{\bar x_1-\bar x_2}{s_p}
$$

where $s_p=\sqrt{\frac{(n_1-1)s_1^2+(n_2-1)s_2^2)}{(n_1+n_2-2)}}$.

Here is an example by hand:

    . webuse lbw
    . logit low age smoke
    . graph box age, by(low)
    . tabstat age, by(low) statistics(mean sd N)

    Summary for variables: age
         by categories of: low (birthweight<2500g)

         low |      mean        sd         N
    ---------+------------------------------
           0 |  23.66154  5.584522       130
           1 |  22.30508  4.511496        59
    ---------+------------------------------
       Total |   23.2381  5.298678       189
    ----------------------------------------

    . display "Cohen's d: = " (23.66154-22.30508) / sqrt((129*(5.584522)^2+58*(4.511496)^2)/187)

    Cohen's d: = .25714326

This is in agreement with what R would give:

    library(MBESS)
    res <- smd(Mean.1=23.66154, Mean.2=22.30508, 
               s.1=5.584522, s.2=4.511496, n.1=130, n.2=59)
    ci.smd(smd=res, n.1=130, n.2=59, conf.level=0.95)

that is an effect size of 0.257 with 95% CI [-0.052;0.566].

In contrast, `sizefx` gives results that differ a little (I have use `separate age, by(low)` and collapse the results in a new data window, here two columns labeled `age0` and `age1`), the ES version calculated above corresponding to what is referred to as Hedge's g below (unless I miss something in the [code][2] I read):

    . sizefx age0 age1
    
    Cohen's d and Hedges' g for: age0 vs. age1
    Cohen's d statistic (pooled variance) = .26721576
    Hedges' g statistic = .26494154
    
    Effect size correlation (r) for: age0 vs. age1
    ES correlation r = .13243109


  [1]: http://econpapers.repec.org/software/bocbocode/s456738.htm
  [2]: http://fmwww.bc.edu/repec/bocode/s/sizefx.ado
