## [Using lmer for prediction](http://stats.stackexchange.com/questions/4187/using-lmer-for-prediction)

Expressing factors relationships using R formulas follows from Wilkinson's notation, where '*' denotes crossing and '/' nesting, but there are some particularities in the way formula for mixed-effects models, or more generally random effects, are handled. For example, two crossed random effects might be represented as `(1|x1)+(1|x2)`. I have interpreted your description as a case of nesting, much like classes are nested in schools (nested in states, etc.), so a basic formula with `lmer` would look like (unless otherwise stated, a `gaussian` family is used by default):

    y ~ x + (1|A:B) + (1|A)

where A and B correspond to your inner and outer factors, respectively. A is nested in B, and both are treated as random factors. In the older [nlme][1] package, this would correspond to something like `lme(y ~ x, random=~ 1 | A/B)`. If A was to be considered as a fixed factor, the formula should read `y ~ x + A + (1|A:B)`. 

But it is worth checking more precisely D. Bates' specifications for the [lme4][2] package, e.g. in his forthcoming textbook, [lme4: Mixed-effects Modeling with R][3], or the many handouts available on the same webpage. In particular, there is an example for such nesting relations in [Fitting Linear Mixed-Effects Models, the lme4 Package in R][4]. John Maindonald's tutorial also provides a nice overview: [The Anatomy of a Mixed Model Analysis, with R’s lme4 Package][5]. Finally, section 3 of the R vignette on [lme4 imlementation][6] includes an example of the analysis of a nested structure.

There is no `predict()` function in [lme4][7], and you have to compute yourself predicted individual values using the estimated fixed (see `?fixeff`) and random (see `?raneff`) effects, but see also this thread on the [lack of predict function in lme4][8]. Still, you can generate a sample from the posterior distribution using the `mcmcsamp()` function. Sometimes, it might clash, though. See the [sig-me][9] mailing list for more updated information.


  [1]: http://cran.r-project.org/web/packages/nlme/index.html
  [2]: http://cran.r-project.org/web/packages/lme4/index.html
  [3]: http://lme4.r-forge.r-project.org/
  [4]: http://www.stat.wisc.edu/~bates/PotsdamGLMM/LMMD.pdf?bcsi_scan_CBA24F92DB3F63E2=0&bcsi_scan_filename=LMMD.pdf
  [5]: http://www.maths.anu.edu.au/~johnm/r-book/xtras/mlm-ohp.pdf
  [6]: http://cran.r-project.org/web/packages/lme4/vignettes/Implementation.pdf
  [7]: http://cran.r-project.org/web/packages/lme4/index.html
  [8]: http://r.789695.n4.nabble.com/no-predict-function-in-lme4-td1679131.html
  [9]: https://stat.ethz.ch/mailman/listinfo/r-sig-mixed-models
