## [Validating questionnaires](http://stats.stackexchange.com/questions/4239/validating-questionnaires)

I will assume that your questionnaire is to be considered as one unidimensional scale (otherwise, Cronbach's alpha doesn't make very much sense). It is worth running an exploratory factor analysis to check for that. It will also allow you to see how items relate to the scale (i.e., through their loadings).

Basic steps for validating your items and your scale should include:

* a complete report on the items' basic statistics (range, quartiles, central tendency, ceiling and floor effects if any);
* checking the internal consistency as you've done with your alpha (best, give 95% confidence intervals, because it is sample-dependent);
* describe you summary measure (e.g., total or mean score, aka scale score) with usual statistics (histogram + density, quantiles etc.);
* check your summary responses against specific covariates which are supposed to be related to the construct your are assessing -- this is referred to as known-group validity;
* if possible, check your summary responses against known instruments that purport to measure the same construct ([concurrent][1] or convergent validity).

If your scale is not unidimensional, these steps have to be done for each subscale, and you could also factor out the correlation matrix of your factors to assess the second-order factor structure (or use structural equation modeling, or confirmatory factor analysis, or whatever you want). You can also assess convergent and discriminant validity by using Multi-trait scaling or Multi-trait multi-method modeling (based on interitem correlations within and between scales), or, again, SEMs.

Then, I would say that Item Response Theory would not help that much unless you are interested in shortening your questionnaire, filtering out some items that show [differential item functioning][2], or use your test in some kind of a [computer adaptive test][3]. 

In any case, the [Rasch model][4] is for binary items. For polytomous ordered items, the most commonly used models are :

* the graded response model
* the partial credit model
* the rating scale model.

Only the latter two are from the Rasch family, and they basically use an adjacent odds formulation, with the idea that subject has to "pass" several thresholds to endorse a given response category. The difference between these two models is that the PCM does not impose that thresholds are equally spaced on the theta (*ability*, or subject location on the latent trait) scale. The graded response model relies on a cumulative odds formulation. Be aware that these models all suppose that the scale is unidimensional; i.e., there's only one latent trait. There are additional assumptions like, e.g., local independence (i.e., the correlations between responses are explained by variation on the ability scale). 

Anyway, you will find a very complete documentation and useful clues to apply psychometric methods in R in volume 20 of the Journal of Statistical Software: [Special Volume: Psychometrics in R][5]. Basically, the most interesting R packages that I use in my daily work are: [ltm][6], [eRm][7], [psych][8], [psy][9]. Others are referenced on the CRAN task view [Psychometrics][10]. Other resources of interest are: 

* [Notes on the use of R for psychology experiments and questionnaires][11]
* [Using R for psychological research][12] (W. Revelle is actually writing a book on [psychometrics in R][13])
* the [PsychoR][14] project (it does not focus on IRT and scale development, though).

A good review on the use of FA vs. IRT in scale development can be found in Scale construction and evaluation in practice: [A review of factor analysis versus item response theory applications][15], by ten Holt et al (Psychological Test and Assessment Modeling (2010) 52(3): 272-297).


  [1]: http://en.wikipedia.org/wiki/Concurrent_validity
  [2]: http://en.wikipedia.org/wiki/Differential_item_functioning
  [3]: http://en.wikipedia.org/wiki/Computerized_adaptive_testing
  [4]: http://en.wikipedia.org/wiki/Rasch_model
  [5]: http://www.jstatsoft.org/v20
  [6]: http://cran.r-project.org/web/packages/ltm/index.html
  [7]: http://cran.r-project.org/web/packages/eRm/index.html
  [8]: http://cran.r-project.org/web/packages/psych/index.html
  [9]: http://cran.r-project.org/web/packages/psy/index.html
  [10]: http://cran.r-project.org/web/views/Psychometrics.html
  [11]: http://www.psych.upenn.edu/~baron/rpsych/rpsych.html
  [12]: http://personality-project.org/r/
  [13]: http://personality-project.org/r/book/
  [14]: http://r-forge.r-project.org/projects/psychor/
  [15]: http://www.ppsw.rug.nl/~boomsma/tenholt_vanduijn_boomsma_2010.pdf
