## [Computing the decision boundary of a linear SVM model](http://stats.stackexchange.com/questions/5056/computing-the-decision-boundary-of-a-linear-svm-model)

The [Elements of Statistical Learning][1], from Hastie et al., has a complete chapter on support vector classifiers and SVMs (in your case, start page 418 on the 2nd edition). Another good tutorial is [Support Vector Machines in R][2], by David Meyer.

Unless I misunderstood your question, the decision boundary (or hyperplane) is defined by $x^T\beta + \beta_0=0$ (with $\|\beta\|=1$, and $\beta_0$ the intercept term), or as @ebony said a linear combination of the support vectors. The margin is then $2/\|\beta\|$, following Hastie et al. notations.

From the on-line help of `ksvm()` in the [kernlab][3] R package, but see also [kernlab – An S4 Package for Kernel Methods in R][4], here is a toy example:


    set.seed(101)
    x <- rbind(matrix(rnorm(120),,2),matrix(rnorm(120,mean=3),,2))
    y <- matrix(c(rep(1,60),rep(-1,60)))
    svp <- ksvm(x,y,type="C-svc")
    plot(svp,data=x)

Note that for the sake of clarity, we don't consider train and test samples.
Results are shown below, where color shading helps visualizing the fitted decision values; values around 0 are on the decision boundary. 

![alt text][5]

Calling `attributes(svp)` gives you attributes that you can access, e.g.

    alpha(svp)  # support vectors whose indices may be 
                # found with alphaindex(svp)
    b(svp)      # (negative) intercept 

So, to display the decision boundary, with its corresponding margin, let's try the following (in the rescaled space), which is largely inspired from a tutorial on SVM made some time ago by [Jean-Philippe Vert][6]:

    plot(scale(x), col=y+2, pch=y+2, xlab="", ylab="")
    w <- colSums(coef(svp)[[1]] * x[unlist(alphaindex(svp)),])
    b <- b(svp)
    abline(b/w[1],-w[2]/w[1])
    abline((b+1)/w[1],-w[2]/w[1],lty=2)
    abline((b-1)/w[1],-w[2]/w[1],lty=2)

And here it is:

![alt text][7]


  [1]: http://www-stat.stanford.edu/~tibs/ElemStatLearn/
  [2]: http://www.ci.tuwien.ac.at/~meyer/svm/final.pdf
  [3]: http://cran.r-project.org/web/packages/kernlab/index.html
  [4]: http://www.jstatsoft.org/v11/i09/paper
  [5]: http://i.imgur.com/oNWf7.png
  [6]: http://cbio.ensmp.fr/~jvert/
  [7]: http://i.imgur.com/ZvQpJ.png
