## [Complex regression plot in R](http://stats.stackexchange.com/questions/7899/complex-regression-plot-in-r)

Does the picture below look like what you want to achieve?

![enter image description here][1]

Here's the **updated** R code, following your comments:

    do.it <- function(df, type="confidence", ...) {
      require(ellipse)
      lm0 <- lm(y ~ x, data=df)
      xc <- with(df, xyTable(x, y))
      df.new <- data.frame(x=seq(min(df$x), max(df$x), 0.1))
      pred.ulb <- predict(lm0, df.new, interval=type)
      pred.lo <- predict(loess(y ~ x, data=df), df.new)
      plot(xc$x, xc$y, cex=xc$number*2/3, xlab="x", ylab="y", ...)
      abline(lm0, col="red")
      lines(df.new$x, pred.lo, col="green", lwd=1.5)
      lines(df.new$x, pred.ulb[,"lwr"], lty=2, col="red")
      lines(df.new$x, pred.ulb[,"upr"], lty=2, col="red")    
      lines(ellipse(cor(df$x, df$y), scale=c(sd(df$x),sd(df$y)), 
            centre=c(mean(df$x),mean(df$y))), lwd=1.5, col="green")
      invisible(lm0)
    }
    
    set.seed(101)
    n <- 1000
    x <- rnorm(n, mean=2)
    y <- 1.5 + 0.4*x + rnorm(n)
    df <- data.frame(x=x, y=y)
            
    # take a bootstrap sample
    df <- df[sample(nrow(df), nrow(df), rep=TRUE),]
    
    do.it(df, pch=19, col=rgb(0,0,.7,.5))

And here is the *ggplotized* version

![enter image description here][2]

produced with the following piece of code:

    xc <- with(df, xyTable(x, y))
    df2 <- cbind.data.frame(x=xc$x, y=xc$y, n=xc$number)
    df.ell <- as.data.frame(with(df, ellipse(cor(x, y), 
                                             scale=c(sd(x),sd(y)), 
                                             centre=c(mean(x),mean(y)))))
    library(ggplot2)
    
    ggplot(data=df2, aes(x=x, y=y)) + 
      geom_point(aes(size=n), alpha=.6) + 
      stat_smooth(data=df, method="loess", se=FALSE, color="green") + 
      stat_smooth(data=df, method="lm") +
      geom_path(data=df.ell, colour="green", size=1.2)

It could be customized a little bit more by adding model fit indices, like Cook's distance, with a color shading effect.

  [1]: http://i.imgur.com/NDRc2.png
  [2]: http://i.imgur.com/MjLli.png
