## [Prediction in simple and multiple ANOVA](http://stats.stackexchange.com/questions/9692/prediction-in-simple-and-multiple-anova)

You can use `lm()` instead of `aov()` in this case (the latter is a wrapper of the former).

Here is an illustration:

    n <- 100
    A <- gl(2, n/2, n, labels=paste("a", 1:2, sep=""))
    B <- gl(2, n/4, n, labels=paste("b", 1:2, sep=""))
    # generate fake data for a balanced two-way ANOVA
    df <- data.frame(y=rnorm(n), A, B)
    summary(lm1 <- lm(y~A+B, data=df)) # compare with summary.aov(...)
    predict(lm1, expand.grid(A=levels(A), B=levels(B)), interval="confidence")

The latter command gives you predictions for each combination of the A and B factor levels (here, I didn't included the interaction), in the following order:


       A  B
    1 a1 b1
    2 a2 b1
    3 a1 b2
    4 a2 b2

Another option is to use the [effects][1] package.


  [1]: http://cran.r-project.org/web/packages/effects/index.html
