## [Recommended procedure for factor analysis on dichotomous data with R](http://stats.stackexchange.com/questions/11372/recommended-procedure-for-factor-analysis-on-dichotomous-data-with-r)

To sum up, with n=45 subjects you're left with correlation-based and multivariate descriptive approaches. However, since this questionnaire is supposed to be unidimensional, this always is a good start.

What I would do:

* Compute pairwise correlations for your 22 items; report the range and the median -- this will give an indication of the relative consistency of observed items responses (correlations above 0.3 are generally thought of as indicative of good convergent validity, but of course the precision of this estimate depends on the sample size); an alternative way to study the internal consistency of the questionnaire would be to compute [Cronbach's alpha][1], although with n=45 the associated confidence interval (use bootstrap for that) will be relatively large.
* Compute [point-biserial correlation][2] between items and the summated scale score; it will give you an idea of the discriminative power of each item (like loadings in FA), where values above 0.3 are indicative of a satisfactory relationship between each item and their corresponding scale.
* Use a PCA to summarize the correlation matrix (it yields an equivalent interpretation to what would be obtained from a [multiple correspondence analysis][3] in case of dichotomously scored items). If your instrument behaves as a unidimensional scale for your sample, you should observe a dominant axis of variation (as reflected by the first eigenvalue).

Should you want to use R, you will find useful function in the [ltm][4] and [psych][5] package; browse the CRAN [Psychometrics][6] Task View for more packages. In case you get 100 subjects, you can try some CFA or SEM analysis with bootstrap confidence interval. (Bear in mind that loadings should be very large to consider there's a significant correlation between any item and its factor, since it should be at least two times the standard error of a reliable correlation coefficient, $2(1-r^2)/\sqrt(n)$.)


  [1]: http://en.wikipedia.org/wiki/Cronbach%27s_alpha
  [2]: http://en.wikipedia.org/wiki/Point-biserial_correlation_coefficient
  [3]: http://en.wikipedia.org/wiki/Multiple_correspondence_analysis
  [4]: http://cran.r-project.org/web/packages/ltm/index.html
  [5]: http://cran.r-project.org/web/packages/psych/index.html
  [6]: http://cran.r-project.org/web/views/Psychometrics.html
