## [Assessing reliability of a questionnaire: dimensionality, problematic items, and whether to use alpha, lambda6 or some other index?](http://stats.stackexchange.com/questions/11628/assessing-reliability-of-a-questionnaire-dimensionality-problematic-items-and)

I think @Jeromy already said the essential so I shall concentrate on measures of reliability.

The Cronbach's alpha is a sample-dependent index used to ascertain a lower-bound of the reliability of an instrument. It is no more than an indicator of variance shared by all items considered in the computation of a scale score. Therefore, it should not be confused with an absolute measure of reliability, nor does it apply to a multidimensional instrument as a whole. In effect, the following assumptions are made: (a) no residual correlations, (b) items have identical loadings, and (c) the scale is unidimensional. This means that the sole case where alpha will be essentially the same as *reliability* is the case of uniformly high factor loadings, no error covariances, and unidimensional instrument (1). As its precision depends on the standard error of items intercorrelations it depends on the spread of item correlations, which means that alpha will reflect this range of correlations regardless of the source or sources of this particular range (e.g., measurement error or multidimensionality). This point is largely discussed in (2). It is worth noting that when alpha is 0.70, a widely refered reliability threshold for group comparison purpose (3,4), the standard error of measurement will be over half (0.55) a standard deviation. 
Moreover, Cronbach alpha is a measure of *internal consistency*, it is not a measure of unidimensionality and can’t be used to infer unidimensionality (5). Finally, we can quote L.J. Cronbach himself,

> Coefficients are a crude device that
> does not bring to the surface many
> subtleties implied by variance
> components. In particular, the
> interpretations being made in current
> assessments are best evaluated through
> use of a standard error of
> measurement. --- Cronbach & Shavelson,
> (6)

There are many other pitfalls that were largely discussed in several papers in the last 10 years (e.g., 7-10).

Guttman (1945) proposed a series of 6 so-called lambda indices to assess a similar lower bound for reliability, and Guttman's $\lambda_3$ lowest bound is strictly equivalent to Cronbach's alpha. If instead of estimating the true variance of each item as the average covariance between items we consider the amount of variance in each item that can be accounted for by the linear regression of all other items (aka, the squared multiple correlation), we get the $\lambda_6$ estimate, which might be computed for multi-scale instrument as well. More details can be found in William Revelle's forthcoming textbook, [An introduction to psychometric theory with applications in R][2] (chapter 7). (He is also the author of the [psych][1] R package.) You might be interested in reading section 7.2.5 and 7.3, in particular, as it gives an overview of alternative measures, like McDonald's $ \omega_t$ or $\omega_h$ (instead of using the squared multiple correlation, we use item uniqueness as determined from an FA model) or Revelle's $\beta$ (replace FA with hierarchical cluster analysis, for a more general discussion see (12,13)), and provide simulation-based comparison of all indices.

## References


1. Raykov, T. (1997). Scale reliability, Cronbach’s coefficient alpha, and violations of essential tau-equivalence for fixed congeneric components. *Multivariate Behavioral Research*, 32, 329-354.
2. Cortina, J.M. (1993). [What Is Coefficient Alpha? An Examination of Theory and Applications][3]. *Journal of Applied Psychology*, 78(1), 98-104.
3. Nunnally, J.C. and Bernstein, I.H. (1994). *Psychometric Theory*. McGraw-Hill Series in Psychology, Third edition.
4. De Vaus, D. (2002). *Analyzing social science data*. London: Sage Publications.
5. Danes, J.E. and Mann, O.K.. (1984). Unidimensional measurement and structural equation models with latent variables. *Journal of Business Research*, 12, 337-352.
6. Cronbach, L.J. and Shavelson, R.J. (2004). [My current thoughts on coefficient alpha and successorprocedures][4]. *Educational and Psychological Measurement*, 64(3), 391-418.
7. Schmitt, N. (1996). [Uses and Abuses of Coefficient Alpha][5]. *Psychological Assessment*, 8(4), 350-353.
8. Iacobucci, D. and Duhachek, A. (2003). [Advancing Alpha: Measuring Reliability With Confidence][6]. *Journal of Consumer Psychology*, 13(4), 478-487.
9. Shevlin, M., Miles, J.N.V., Davies, M.N.O., and Walker, S. (2000). [Coefficient alpha: a useful indicator of reliability?][7] *Personality and Individual Differences*, 28, 229-237.
10. Fong, D.Y.T., Ho, S.Y., and Lam, T.H. (2010). [Evaluation of internal reliability in the presence of inconsistent responses][8]. *Health and Quality of Life Outcomes*, 8, 27.
11. Guttman, L. (1945). A basis for analyzing test-retest reliability. *Psychometrika*, 10(4), 255-282.
12. Zinbarg, R.E., Revelle, W., Yovel, I., and Li, W. (2005). [Cronbach's $alpha$, Revelle's $\beta$, and McDonald's $\omega_h$: Their relations with each other and two alternative conceptualizations of reliability][9]. *Psychometrika*, 70(1), 123-133.
13. Revelle, W. and Zinbarg, R.E. (2009) [Coefficients alpha, beta, omega and the glb: comments on Sijtsma][10]. *Psychometrika*, 74(1), 145-154


  [1]: http://cran.r-project.org/web/packages/psych/index.html
  [2]: http://personality-project.org/r/book/
  [3]: http://psychweb.psy.umt.edu/denis/datadecision/front/cortina_alpha.pdf
  [4]: http://psych.unl.edu/psycrs/971/scale/cronbach_on_alpha.pdf
  [5]: http://socrates.berkeley.edu/~maccoun/PP279_Schmitt.pdf
  [6]: http://www.owen.vanderbilt.edu/vanderbilt/data/research/2190full.pdf
  [7]: http://www.jeremymiles.co.uk/mestuff/publications/p6.pdf
  [8]: http://www.hqlo.com/content/8/1/27
  [9]: http://www.personality-project.org/revelle/publications/zinbarg.revelle.pmet.05.pdf
  [10]: http://www.personality-project.org/revelle/publications/revelle.zinbarg.08.pdf
