## [How do I compute class probabilities in caret package using 'glmnet' method?](http://stats.stackexchange.com/questions/26084/how-do-i-compute-class-probabilities-in-caret-package-using-glmnet-method)

I suspect your `y` is of class `numeric` and is not an R `factor`. You can look at the documentation for `glmnet` directly, 

       y: response variable. Quantitative for ‘family="gaussian"’ or
          ‘family="poisson"’ (non-negative counts). For
          ‘family="binomial"’ should be either a **factor with two
          levels, or a two-column matrix of counts or proportions**.
(emphasize is mine.)

or check it with the following toy example:

    library(caret)
    data(iris)
    iris.sub <- subset(iris, Species %in% c("setosa", "versicolor"))
    train(iris.sub[,1:4], factor(iris.sub$Species), method='glmnet', 
          trControl=trainControl(classProbs=TRUE))  # work
    train(iris.sub[,1:4], as.numeric(iris.sub$Species), method='glmnet', 
          trControl=trainControl(classProbs=TRUE))  # 'cannnot compute class probabilities for regression'

