## [Under what conditions can a PLS regression model be expressed by single linear equation?](http://stats.stackexchange.com/questions/31678/under-what-conditions-can-a-pls-regression-model-be-expressed-by-single-linear-e)

There is a good summary of PLS regression in

> Rosipal, R and Krämer, N (2006). [Overview and recent advances in
> Partial Least
> Squares](http://www.meduniwien.ac.at/user/roman.rosipal/Papers/pls_book06.pdf).
> In Saunder, C, Grobelnik, M, Gunn, S, and Shawe-Taylors (Eds.),
> *Subspace, Latent Structure and Feature Selection*, pp. 34-51, Springer.

Using your notation, where $P$ and $Q$ are matrices of loadings, of
dimensions $(N\times p)$ and $(M\times p)$, and $T$ and $U$ are $(n\times
p)$ matrices of $p$ scores for $n$ individuals ($p\le\min(n,N)$), component
scores are constructed as $t=Xw$ and $u=Yc$, and we find orthogonal weight
vectors, $w$ and $c$, by maximizing covariance between $t$ and $u$, with
appropriate constraints on $w$ and $c$ ($\|w\|=\|c\|=1$).
This is usually done iteratively using the popular NIPALS algorithm, but
other methods have been proposed (SVD, SIMPLS), and different models of PLS
lead to different deflation strategies. A good overview is available in 

1. Wegelin, JA
(200). [A Survey of Partial Least Squares (PLS) Methods, with Emphasis on the Two-Block Case](http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.30.16). Technical
Report, Department of Statistics, Univeristy of Washington, Seattle.
2. Höskuldsson, A
(1988). [PLS regression methods](http://siba.unipv.it/fisica/articoli/J/JournalOfChemometrics1988_2_3_211.pdf). *Journal
of Chemometrics*, 2, 211-228.

(The [chemometrics](http://cran.r-project.org/web/packages/chemometrics/) R
vignette gives a short overview as well.)

In PLS regression (with a single or multiple outcomes, aka PLS-2), **we
further assume a linear (*inner*) relation between the components scores**,
$U=TD+H$, where $D$ is a $(p\times p)$ diagonal matrix of weights, and $H$
is the matrix of residuals. Therefore, following Rosipal and Krämer's
notation, the $Y$ matrix can be decomposed as follows:
$$Y=TDQ^T+\underbrace{(HQ^T+F)}_{residuals}$$
which is roughly an OLS decomposition considering the orthogonal predictors
$T$, and where $C^T=DQ^T$ is the $(p\times M)$ matrix of regression
coefficients. Its estimate can be computed as $\hat C=(T^TT)^{-1}T^TY$. 

It is also possible to express the PLS regression model using the observed
block $X$ directly, as $Y=XB+(HQ^T+F)$. Using the fact that
$T=XW(P^TW)^{-1}$ ($T^TT=\mathbb I_p$), Rosipal and Krämer shows that the
regression coefficients are then estimated as $\hat
B=X^TU(T^TXX^TU)^{-1}T^TY$. This allows to express separate $\hat y$ (in
case of PLS-2) as a linear combination of the $x_i$ ($i=1,\dots,N$).
