## [Confidence intervals on differences in choices in a GEE framework: methods and alternatives?](http://stats.stackexchange.com/questions/2537/confidence-intervals-on-differences-in-choices-in-a-gee-framework-methods-and-al)

Well, the [gee][1] package includes facilities for fitting GEE and `gee()` return asymptotic and robust SE. I never used the [geepack][2] package. From what I saw in the online example, output seems to resemble more or less that of `gee`. To compute $100(1-\alpha)$ CIs for your main effects (e.g. gender), why not use the robust SE (in the following I will assume it is extracted from, say `summary(gee.fit)`, and stored in a variable `rob.se`)? I suppose that

    exp(coef(gee.fit)["gender"]+c(-1,1)*rob.se*qnorm(0.975))

should yield 95% CIs expressed on the odds scale.

Now, in fact I rarely use GEE except when I am working with binary endpoints in longitudinal studies, because it's easy to pass or estimate a given working correlation matrix. In the case you summarize here, I would rather rely on an IRT model for dichotomous items (see the [psychometrics][3] task view), or (it is quite the same in fact) a mixed-effects GLM such as the one that is proposed in the [lme4][4] package, from Doug Bates. For study like yours, as you said, subjects will be considered as random effects, and your other covariates enter the model as fixed effects; the response is the 0/1 rating on each item (which enter the model as well). Then you will get 95% CI for fixed effects, either from the SE computed as `sqrt(diag(vcov(glmm.fit)))` or as read in `summary(glmm.fit)`, or using `confint()` together with an `lmList` object. Doug Bates gave nice illustrations in the following two paper/handout:

* [Estimating the Multilevel Rasch Model: With the lme4 Package][5] (JSS, 2007 20(2))
* [Item Response Models as GLMMs][6] (from a workshop at UseR 2008)

There is also a discussion about profiling `lmer` fits (based on *profile deviance*) to investigate variability in fixed effects, but I didn't investigate that point. I think it is still in section 1.5 of Doug's [draft on mixed models][7]. There are a lot of discussion about computing SE and CI for GLMM as implemented in the `lme4` package (whose interface differs from the previous `nlme` package), so that you will easily find other interesting threads after googling about that. 

It's not clear to me why GEE would have to be preferred in this particular case. Maybe, look at the R translation of Agresti's book by Laura Thompson, [R (and S-PLUS) Manual to Accompany Agresti's Categorical Data][8].

<hr />
**Update:**

I just realized that the above solution would only work if you're interested in getting a confidence interval for the gender effect alone. If it is the interaction item*gender that is of concern, you have to model it explicitly in the GLMM (my second reference on Bates's has an example on how to do it with `lmer`). 

Another solution is to use an explanatory IRT model, where you explicitly acknowledge the potential effect of person covariates, like gender or age, and consider fitting them within a Rasch model, for example. This is called a Latent Regression Rasch Model, and is fully described in de Boeck and Wilson's book, _Explanatory item response models: a generalized linear and nonlinear approach_ (Springer, 2004), which you can read online on [Google books][9] (section 2.4). There are some facilities to fit this kind of model in Stata (see [there][10]). In R, we can mimic such model with a mixed-effects approach; a toy example would look something like

    lmer(response ~ 0 + Age + Sex + item + (Sex|id), data=df, binomial)

if I remember correctly. I'm not sure whether the [eRm][11] allows to easily incorporate person covariates (because we need to construct a specific design matrix), but it may be worth checking out since it provides 95% CIs too.


  [1]: http://cran.r-project.org/web/packages/gee/index.html
  [2]: http://cran.r-project.org/web/packages/geepack/index.html
  [3]: http://cran.r-project.org/web/views/Psychometrics.html
  [4]: http://cran.r-project.org/web/packages/lme4/index.html
  [5]: http://www.jstatsoft.org/v20/i02
  [6]: http://www.stat.wisc.edu/~bates/UseR2008/WorkshopD.pdf
  [7]: http://lme4.r-forge.r-project.org/book/
  [8]: https://home.comcast.net/~lthompson221/Splusdiscrete2.pdf
  [9]: http://books.google.fr/books?id=pDeLy5L14mAC&pg=PA66&lpg=PA66&dq=latent+regression+Rasch+model&source=bl&ots=Ivct9snqQO&sig=okSBDj9TAe5gZHIcMDHOQxvAbZU&hl=fr&ei=q0yKTPlCgYDgBq-CrdoK&sa=X&oi=book_result&ct=result&resnum=7&ved=0CEMQ6AEwBg#v=onepage&q=latent%20regression%20Rasch%20model&f=false
  [10]: http://www.gllamm.org/aggression.html
  [11]: http://cran.r-project.org/web/packages/eRm/index.html
