## [Patient distance metrics](http://stats.stackexchange.com/questions/3419/patient-distance-metrics)

You asked a difficult question, but I'm a little bit surprised that the various clues that were suggested to you received so little attention. I upvoted all of them because I think they basically are useful responses, though in their actual form they call for further bibliographic work.

**Disclaimer:** I never had to deal with such a problem, but I regularly have to expose statistical results that may differ from physician's *a priori* beliefs and I learn a lot from unraveling their lines of reasoning. Also, I have some background in teaching human decision/knowledge from the perspective of Artificial Intelligence and Cognitive Science, and I think what you asked is not so far from how experts actually decide that two objects are similar or not, based on their attributes and a common understanding of their relationships.

From your question, I noticed two interesting assertions. The first one related to how an expert assess the similarity or difference between two set of measurements:

> I don't particularly care if there is
> some relation between attribute X and
> Y. What I care about is if a doctor
> thinks there is a relation between X
> and Y.

The second one, 

> How can I predict what they think the
> similarity is? Do they look at certain
> attributes?

looks like it is somewhat subsumed by the former, but it seems more closely related to what are the most salient attributes that allow to draw a clear separation between the objects of interest.

To the first question, I would answer: Well, if there is no characteristic or objective relationship between any two subjects, what would be the rationale for making up an hypothetical one? Rather, I think the question should be: If I only have limited resources (knowledge, time, data) to take a decision, how do I optimize my choice? To the second question, my answer is: Although it seems to partly contradicts your former assertion (if there is no relationship at all, it implies that the available attributes are not discriminative or useless), I think that most of the time this is a combination of attributes that makes sense, and not only how a given individual scores on a single attribute.

Let me dwell on these two points.
Human beings have a limited or [bounded rationality][1], and can take a decision (often the right one) without examining all possible solutions. There is also a close connection with [abductive reasoning][2].
It is well known that there is some variability between individual judgments, and even between judgments from the same expert at two occasions. This is what we are interested in in reliability studies. But you want to know how these experts elaborate their judgments. There is a huge amount of papers about that in cognitive psychology, especially on the fact that *relative judgments* are easier and more reliable than *absolute* ones. Doctors' decisions are interesting in this respect because they are able to take a "good" decision with a limited amount of information, but at the same time they benefit from an ever growing internal knowledge base from which they can draw expected relationships (extrapolation). In other words, they have a built-in inference (assumed to be hypothetico-deductive) machinery and accumulate positive evidence or counterfactuals from there experience or practice. Reproducing this inferential ability and the use of declarative knowledge was the aim of several expert or [production rule][3] systems in the 70s, the most famous one being [MYCIN][4], and more generally of Artifical Intelligence earlier in 1946 (Can we reproduce on an artificial system the intelligent behavior observed in man?). Automatic treatment of speech, problem solving, visual shape recognition are still active projects nowadays and they all have to do with identifying salient features and their relationships to make an appropriate decision (i.e., how far should two patterns be to be judged as the emanation of two distinct generating processes?).

In sum, our doctors are able to draw an optimal inference from a limited amount of data, compensating from noise that arises simply as a byproduct of individual variability (at the level of the patients). Thus, there is a clear connection with statistics and probability theory, and the question is what conscious or subconscious methodology help doctors forming their judgments. [Semantic networks][5] (SN), [belief networks][6], and [decision trees][7] are all relevant to the question you asked. The paper you cited is about using an [ontology][8] as a basis of formal judgments, but it is no more than an extension of SNs, and many projects were initiated in this direction (I can think of the [Gene Ontology][9] for genomic studies, but many others exist in different domains). 

Now, look at the following hierarchical classification of diagnostic categories (it is roughly taken from Dunn 1989, p. 25):

![alt text][10]

And now take a look at the [ICD classification][11]; I think it is not too far from this schematic classification. Mental disorders are organized into distinct categories, some of them being closer one to each other. What render them similar is the closeness of their expression (phenotype) in any patient, and the fact that they share some similarities in their somatic/psychological etiology. Assessing whether two doctors would make the same diagnostic is a typical example of an *inter-rater agreement* study, where two psychiatrists are asked to place each of several patients in mutually exclusive categories. The hierarchical structure should be reflected in the disagreement between each doctor, that is they may not agree on the finer distinction between diagnostic classes (the leafs) but if they were to disagree between insomnia and schizophrenia, well it would be little bit disconcerting... How these two doctors decide on which class a given patient belongs to is no more than a clustering problem: How likely are two individuals, given a set of observed values on different attributes, to be similar enough so that I decide they share the same class membership? 

Now, some attributes are more influential than others, and this is exactly what is reflected in the weight attributed to a given attribute in Latent Class Analysis (which can be thought of as a [probabilistic extension][12] of clustering methods like k-means), or the [variable importance][13] in Random Forests. We need to put things into boxes, because at first sight it's simpler. The problem is that often things overlap to some extent, so we need to consider different levels of categorization.
In fact, *cluster analysis* is at the heart of the actual DSM categories, and many papers actually turn around assigning one patient to a specific syndromic category, based on the profile of his response to a battery of neuropsychological assessments. This merely looks like a *subtyping* approach; each time, we seek to refine a preliminary well-established diagnostic category, by adding exception rules or an additional relevant symptom or impairment. 

A related topic is *decision trees* which are by far the most well understood statistical techniques by physicians. Most of the time, they described a nested series of boolean assertions (Do you have a sore throat? If yes, do you have a temperature? etc.; but look at an example of public [influenza diagnostic tree][14]) according to which we can form a decision regarding patients proximity (i.e. how similar patients are wrt. attributes considered for building the tree -- the closer they are the more likely they are to end up in the same leaf). [Association rules][15] and the  [C4.5 algorithm][16] rely quite on the same idea. On a related topic, there's the [patient rule-induction method][17] (PRIM). Now clearly, we must make a distinction between all those methods, that make an efficient use of a large body of data and incorporate bagging or boosting to compensate for model fragility or overfitting issues, and doctors who cannot process huge amount of data in an automatic and algorithmic manner. But, for small to moderate amount of descriptors, I think they perform quite good after all.

The yes-or-no approach is not the panacea, though. In behavioral genetics and psychiatry, it is commonly argued that the classification approach is probably not the best way to go, and that common diseases (learning disorders, depression, personality disorders, etc.) reflect a continuum rather than classes of opposite valence. Nobody's perfect!

In conclusion, I think doctors actually hold a kind of internalized inference engine that allows them to assign patients into distinctive classes that are characterized by a weighted combination of available evidences; in other words, they are able to organize their knowledge in an efficient manner, and these internal representations and the relationships they share may be augmented throughout experience. [Case-based reasoning][18] probably comes into play at some point too. All of this may be subjected to (a) revision with newly available data (we are not simply acting as definitive binary classifiers, and are able to incorporate new data in our decision making), and (b) subjective biases arising from past experience or wrong self-made association rules. However, they are prone to errors, as every decision systems...

All statistical techniques reflecting these steps -- decisions trees, bagging/boosting, cluster analysis, latent cluster analysis -- seems relevant to your questions, although they may be hard to instantiate in a single decision rule. 

Here are a couple of references that might be helpful, as a first start to how doctors make their decisions:

* [A clinical decision support system for clinicians for determining appropriate radiologic imaging examination][19]
* Grzymala-Busse, JW. [Selected Algorithms of Machine Learning from Examples][20]. *Fundamenta Informaticae* 18 (1993), 193–207
* Santiago Medina, L, Kuntz, KM, and Pomeroy, S. [Children With Headache Suspected of Having a Brain Tumor: A Cost-Effectiveness Analysis of Diagnostic Strategies][21]. *Pediatrics* 108 (2001), 255-263
* [Building Better Algorithms for the Diagnosis of Nontraumatic Headache][22]
* Jenkins, J, Shields, M, Patterson, C, and Kee, F. [Decision making in asthma exacerbation: a clinical judgement analysis][23]. Arch Dis Child 92 (2007), 672–677
* Croskerry, P. [Achieving quality in clinical decision making: cognitive strategies and detection of bias][24]. Acad Emerg Med 9(11) (2002), 1184-204.
* Cahan, A, Gilon, D, Manor, O, and Paltiel. [Probabilistic reasoning and clinical decision-making: do doctors overestimate diagnostic probabilities?][25] QJM 96(10) (2003), 763-769
* Wegwarth, O, Gaissmaier, W, and Gigerenzer, G. [Smart strategies for doctors and doctors-in-training: heuristics in medicine][26]. Medical Education 43 (2009), 721–728


  [1]: http://en.wikipedia.org/wiki/Bounded_rationality
  [2]: http://en.wikipedia.org/wiki/Abduction_(logic)
  [3]: http://en.wikipedia.org/wiki/Production_system
  [4]: http://en.wikipedia.org/wiki/Mycin
  [5]: http://en.wikipedia.org/wiki/Semantic_network
  [6]: http://en.wikipedia.org/wiki/Bayesian_network
  [7]: http://en.wikipedia.org/wiki/Decision_tree
  [8]: http://en.wikipedia.org/wiki/Ontology_(information_science)
  [9]: http://www.geneontology.org/
  [10]: http://i.imgur.com/y3t62.png
  [11]: http://ICD9Data.com/
  [12]: http://www.statisticalinnovations.com/articles/kmeans2a.htm
  [13]: http://www.stat.berkeley.edu/~breiman/RandomForests/cc_home.htm
  [14]: http://www.crengland.com/content/managementservices/flu/flu-decision-tree.pdf
  [15]: http://en.wikipedia.org/wiki/Association_rule_learning
  [16]: http://en.wikipedia.org/wiki/C4.5_algorithm
  [17]: http://www.ijmijournal.com/article/S1386-5056(07)00122-0/abstract
  [18]: http://en.wikipedia.org/wiki/Case-based_reasoning
  [19]: http://www.informatica2009.sld.cu/Members/fatihozbek/a-clinical-decision-support-system-for-clinicians-for-determining-appropriate-radiolog131c-imaging-examination/at_download/trabajo
  [20]: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.86.2566&rep=rep1&type=pdf
  [21]: http://ec.digaden.edu.mx/moodle/moodledata/99/01medint/08_9neuder/30cef/113d255.pdf
  [22]: http://www.psychiatrictimes.com/display/article/10168/57556
  [23]: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC2083892/pdf/672.pdf
  [24]: http://www.crnns.ca/documents/AEM%20Ms%20-%20Achieving%20Quality%20in%20Decision%20MakingEducation%20copyPC.pdf
  [25]: http://qjmed.oxfordjournals.org/content/96/10/763.full.pdf+html
  [26]: http://library.mpib-berlin.mpg.de/ft/ow/OW_Smart_2009.pdf
