## [Item Analysis for an R newbie](http://stats.stackexchange.com/questions/3915/item-analysis-for-an-r-newbie)

I can suggest you at least two packages that allow to perform these tasks: [psych][1] (`score.items`) and [ltm][2] (`descript`). The [CTT][3] package seems also to process MCQ but I have no experience with it. More information can be found on W Revelle's website, [The Personality Project][4], esp. the page dedicated to [psychometrics with R][5] which provides step-by-step instructions for importing, analyzing and report data. Also, the CRAN Task View on [Psychometrics][6] includes many additional resources.

As described in your link, MC stands for "Mean total raw score of the persons who answered the item with the correct response", and MI for "Mean total score of the persons who did not answer the item with the correct response.". Point-biserial correlation (R(IT)) is also available in the `ltm` package (`biserial.cor`). This is basically an indicator of the discrimination power of the item (since it is the correlation of item and total score), and is related to the discrimination parameter of a 2-PL IRT model or factor loading in Factor Analysis.

If you really want to reproduce the table you show, I guess you will have to wrap some of this code with custom code, at least to output the same kind of table. I've made a [quick and dirty example][7] which reproduce your table:

    dat <- replicate(10, sample(LETTERS[1:4], 100, rep=TRUE))
    dat[3,2] <- dat[67,5] <- NA
    itan(dat)
    
             P      R    MC    MI NC OMIT  A  B  C  D
     [1,] 0.23 -0.222 2.870 2.169 23    0 23 22 32 23
     [2,] 0.32 -0.378 3.062 1.985 32    1 32 20 14 33
     [3,] 0.18 -0.197 2.889 2.207 18    0 18 33 22 27
     [4,] 0.33 -0.467 3.212 1.896 33    0 33 18 29 20
     [5,] 0.27 -0.355 3.111 2.056 27    1 27 23 23 26
     [6,] 0.17 -0.269 3.118 2.169 17    0 17 25 25 33
     [7,] 0.21 -0.260 3.000 2.152 21    0 21 24 25 30
     [8,] 0.24 -0.337 3.125 2.079 24    0 24 32 22 22
     [9,] 0.13 -0.218 3.077 2.218 13    0 13 29 33 25
    [10,] 0.25 -0.379 3.200 2.040 25    0 25 25 31 19

As these are random responses, biserial correlation and item difficulty are not very meaningful (except to check that data are truly random :). Also, it is worth checking for possible errors, since I drafted the R function in 10'...


  [1]: http://cran.r-project.org/web/packages/psych/index.html
  [2]: http://cran.r-project.org/web/packages/ltm/index.html
  [3]: http://cran.r-project.org/web/packages/CTT/index.html
  [4]: http://www.personality-project.org/
  [5]: http://www.personality-project.org/r/r.guide.html
  [6]: http://cran.r-project.org/web/views/Psychometrics.html
  [7]: http://gist.github.com/642219
