## [Does it ever make sense to treat categorical data as continuous?](http://stats.stackexchange.com/questions/539/does-it-ever-make-sense-to-treat-categorical-data-as-continuous)

I will assume that a "categorical" variable actually stands for an ordinal variable, otherwise it doesn't make much sense to treat it as a continuous one, unless it's a binary variable (coded 0/1) as pointed by @Rob. Then, I would say that the problem is not that much the way we treat the variable, although many models for categorical data analysis have been developed so far--see e.g., [The analysis of ordered categorical data: An overview and a survey of recent developments][1] from Liu and Agresti--, than the underlying measurement scale we assume. My response will focus on this second point, although I will first briefly discuss the assignment of numerical scores to variable categories or levels.

By using a simple numerical recoding of an ordinal variable, you are assuming that the variable has interval properties (in the sense of the classification given by Stevens, 1946). From a measurement theory perspective (in psychology), this may often be a too strong assumption, but for basic study (i.e. where a single item is used to express one's opinion about a daily activity with clear wording) any monotone scores should give comparable results. Cochran (1954) already pointed that

> any set of scores gives a *valid*
> test, provided that they are
> constructed without consulting the
> results of the experiment. If the set
> of scores is poor, in that it badly
> distorts a numerical scale that really
> does underlie the ordered
> classification, the test will not be
> sensitive. The scores should therefore
> embody the best insight available
> about the way in which the
> classification was constructed and
> used.

(Many thanks to @whuber for reminding me about this throughout one of his comments, which lead me to re-read Agresti's book from which this citation comes from)

Actually, several tests treat implicitly such variables as interval scales; for example, the $M^2$ statistic for testing a linear trend (as an alternative to simple independence) is based on a correlational approach ($M^2=(n-1)r^2$, Agresti, 2002, p. 87). 

Well, you can also decide to recode your variable on an irregular range, or aggregate some of its levels, but in this case strong imbalance between recoded categories may distort statistical tests, e.g. the aforementioned trend test. 
A nice alternative for assigning distance between categories was already proposed by @Jeromy, namely optimal scaling. 

Now, let's discuss the second point I made, that of the underlying measurement model. I'm always hesitating about adding the "psychometrics" tag when I see this kind of question, because the construction and analysis of measurement scales come under Psychometric Theory (Nunnally and Bernstein, 1994, for a neat overview). I will not dwell on all the models that are actually headed under the [Item Response Theory][2], and I kindly refer the interested reader to I. Partchev's tutorial, [A visual guide to item response theory][3], for a gentle introduction to IRT, and to references (5-8) listed at the end for possible IRT taxonomies. Very briefly, the idea is that rather than assigning arbitrary distances between variable categories, you assume a latent scale and estimate their location on that continuum, together with individuals ability or liability. A simple example is worth several mathematical notation, so let's consider the following item (coming from the [EORTC QLQ-C30][4] health-related quality of life questionnaire):

> Did you worry?

which is coded on a four-point scale, ranging from "Not at all" to "Very much". Raw scores are computed by assigning a score of 1 to 4. Scores on items belonging to the same scale can then be added together to yield a so-called scale score, which denotes one's *rank* on the underlying construct (here, a mental health component). Such summated scale scores are very practical because of scoring easiness (for the practician or nurse), but they are nothing more than a discrete (ordered) scale. 

We can also consider that the probability of endorsing a given response category obeys some kind of a logistic model, as described in I. Partchev's tutorial, referred above. Basically, the idea is that of a kind of threshold model (which lead to equivalent formulation in terms of the proportional or cumulative odds models) and we model the odds of being in one response category rather the preceding one or the odds of scoring above a certain category, conditional on subjects' location on the latent trait. In addition, we may impose that response categories are equally spaced on the latent scale (this is the Rating Scale model)--which is the way we do by assigning regularly spaced numerical scores-- or not (this is the Partial Credit model). 

Clearly, we are not adding very much to Classical Test Theory, where ordinal variable are treated as numerical ones. However, we introduce a probabilistic model, where we assume a continuous scale (with interval properties) and where specific errors of measurement can be accounted for, and we can plug these factorial scores in any regression model.

**References**

1. S S Stevens. On the theory of scales of measurement. *Science*, **103**: 677-680, 1946.
2. W G Cochran. Some methods of strengthening the common $\chi^2$ tests. *Biometrics*, **10**: 417-451, 1954.
3. J Nunnally and I Bernstein. *Psychometric Theory*. McGraw-Hill, 1994
4. Alan Agresti. *Categorical Data Analysis*. Wiley, 1990.
5. C R Rao and S Sinharay, editors. *Handbook of Statistics, Vol. 26: Psychometrics*. Elsevier Science B.V., The Netherlands, 2007.
6. A Boomsma, M A J van Duijn, and T A B Snijders. *Essays on Item Response Theory*. Springer, 2001.
7. D Thissen and L Steinberg. A taxonomy of item response models. *Psychometrika*, **51(4)**: 567–577, 1986.
8. P Mair and R Hatzinger. [Extended Rasch Modeling: The eRm Package for the Application of IRT Models in R][5]. *Journal of Statistical Software*, **20(9)**, 2007.


  [1]: http://petra.euitio.uniovi.es/~i1770184/Archivos/t141/Test_agresti.pdf
  [2]: http://en.wikipedia.org/wiki/Item_response_theory
  [3]: http://www.metheval.uni-jena.de/irt/VisualIRT.pdf
  [4]: http://groups.eortc.be/qol/questionnaires_qlqc30.htm
  [5]: http://www.jstatsoft.org/v20/i09
