## [When to use regularization methods for regression?](http://stats.stackexchange.com/questions/4272/when-to-use-regularization-methods-for-regression)

Short answer: Whenever you are facing one of these situations: large number of variables or low ratio of no. observations to no. variables (including the $n\ll p$ case), high collinearity, seeking for a sparse solution (i.e., embed feature selection when estimating model parameters), or accounting for variables grouping in high-dimensional data set.

Ridge regression generally yields better predictions than OLS solution, through a better compromise between bias and variance. Its main drawback is that all predictors are kept in the model, so it is not very interesting if you seek a parcimonious model or want to apply some kind of feature selection. 

To achieve sparsity, the lasso is more appropriate but it will not necessarily yield good results in presence of high collinearity (it has been observed that if predictors are highly correlated, the prediction performance of the lasso is dominated by ridge regression). The second problem with L1 penalty is that the lasso solution is not uniquely determined when the number of variables is greater than the number of subjects (this is not the case of ridge regression). The last drawback of lasso is that it tends to select only one variable among a group of predictors with high pairwise correlations. In this case, there are alternative solutions like the [group][1] (i.e., achieve shrinkage on block of covariates, that is some blocks of regression coefficients are exactly zero) or [fused][2] lasso. The [Graphical Lasso][3] also offers promising features for GGMs (see the R [glasso][4] package).

But, definitely, the *elasticnet* criteria, which is a combination of L1 and L2 penalties achieve both shrinkage and automatic variable selection, and it allows to keep $m>p$ variables in the case where $n\ll p$. Following Zou and Hastie (2005), it is defined as the argument that minimizes (over $\beta$)

$$
L(\lambda_1,\lambda_2,\mathbf{\beta}) = \|Y-X\beta\|^2 + \lambda_2\|\beta\|^2 + \lambda_1\|\beta\|_1
$$

where $\|\beta\|^2=\sum_{j=1}^p\beta_j^2$ and $\|\beta\|^1=\sum_{j=1}^p|\beta_j |$.

The lasso can be computed with an algorithm based on coordinate descent as described in the recent paper by Friedman and coll., [Regularization Paths for Generalized Linear Models via Coordinate Descent][5] (JSS, 2010) or the LARS algorithm. In R, the [penalized][6], [lars][7] or [biglars][8], and [glmnet][9] packages are useful packages; in Python, there's the [scikit.learn][10] toolkit, with extensive [documentation][11] on the algorithms used to apply all three kind of regularization schemes.

As for general references, the [Lasso page][12] contains most of what is needed to get started with lasso regression and technical details about L1-penalty, and this related question features essential references, [When should I use lasso vs ridge?][13]


  [1]: http://www-stat.stanford.edu/~tibs/ftp/sparse-grlasso.pdf
  [2]: http://www.stanford.edu/group/SOL/papers/fused-lasso-JRSSB.pdf
  [3]: http://www-stat.stanford.edu/~tibs/glasso/index.html
  [4]: http://cran.r-project.org/web/packages/glasso/index.html
  [5]: http://www.jstatsoft.org/v33/i01/paper
  [6]: http://cran.r-project.org/web/packages/penalized/index.html
  [7]: http://cran.r-project.org/web/packages/lars/index.html
  [8]: http://cran.r-project.org/web/packages/biglars/index.html
  [9]: http://cran.r-project.org/web/packages/glmnet/index.html
  [10]: http://scikit-learn.sourceforge.net/
  [11]: http://scikit-learn.sourceforge.net/modules/glm.html#lars-algorithm
  [12]: http://www-stat.stanford.edu/~tibs/lasso.html
  [13]: http://stats.stackexchange.com/questions/866/when-should-i-use-lasso-vs-ridge
