## [Doing correlation on one variable vs many](http://stats.stackexchange.com/questions/6020/doing-correlation-on-one-variable-vs-many)

To help you get started with the visualization, here is a snippet of R code with simulated data (a matrix with age and counts for 20 words, arranged in columns, for 100 subjects). The computation are done as proposed my @mbq (correlation).

    n <- 100  # No. subjects
    k <- 20   # No. words
    words <- paste("word", 1:k, sep="")
    df <- data.frame(age=rnorm(n, mean=25, sd=5), 
                     replicate(k, sample(1:10, n, rep=T)))
    colnames(df)[2:(k+1)] <- words
    robs <- sort(cor(as.matrix(df))[-1,1])
    
    library(lattice)
    my.cols <- colorRampPalette(c("red","blue"))
    res <- data.frame(robs=robs, x=seq(1,20), y=rep(1,20))
    
    trellis.par.set(clip=list(panel="off"), axis.line=list(col="transparent"))
    levelplot(robs~y*x, data=res, col.regions=my.cols, 
              colorkey=F, xlab="", ylab="", scales=list(draw=F),
              panel=function(...) {
                panel.levelplot(...)
                panel.text(x=rep(1, k), y=seq(1, k), lab=rownames(res))
             })

![alt text][1]

The above picture was saved as PDF, setting the margins to 1, and croped with `pdfcrop` from my TeXLive distribution.

    pdf("1.pdf")
    op <- par(mar=c(1,1,1,1))
    (...)
    par(op)
    dev.off()

I guess it would not be too difficult to make a similar looking chart with `barchart()` from [lattice][2], or `ggfluctuation()` or any other `qplot()` from [ggplot2][3].


  [1]: http://i.imgur.com/n23ot.png
  [2]: http://cran.r-project.org/web/packages/lattice/index.html
  [3]: http://cran.r-project.org/web/packages/ggplot2/index.html
