## [How to measure/rank “variable importance” when using CART? (specifically using {rpart} from R)](http://stats.stackexchange.com/questions/6478/how-to-measure-rank-variable-importance-when-using-cart-specifically-using-r)

Variable importance might generally be computed based on the corresponding reduction of predictive accuracy when the predictor of interest is removed (with a permutation technique, like in Random Forest) or some measure of decrease of node impurity, but see (1) for an overview of available methods. An obvious alternative to CART is RF of course ([randomForest][2], but see also [party][3]). With RF, the Gini importance index is defined as the averaged Gini decrease in node impurities over all trees in the forest (it follows from the fact that the Gini impurity index for a given parent node is larger than the value of that measure for its two daughter nodes, see e.g. (2)).

I know that Carolin Strobl and coll. have contributed a lot of simulation and experimental studies on (conditional) variable importance in RFs and CARTs (e.g., (3-4), but there are many other ones, or her thesis, [Statistical Issues in Machine Learning – Towards Reliable Split Selection and Variable Importance Measures][1]).

To my knowledge, the [caret][4] package (5) only considers a loss function for the regression case (i.e., mean squared error). Maybe it will be added in the near future (anyway, an example with a classification case by k-NN is available in the on-line help for `dotPlot`). 

However, Noel M O'Boyle seems to have some R code for [Variable importance in CART][5].

**References**

1. Sandri and Zuccolotto. [A bias correction algorithm for the Gini variable importance measure in classification trees](http://www.msandri.it/docs/Sandri_Zuccolotto_2.pdf). 2008
2. Izenman. *Modern Multivariate Statistical Techniques*. Springer 2008
3. Strobl, Hothorn, and Zeilis. [Party on!](http://journal.r-project.org/archive/2009-2/RJournal_2009-2_Strobl~et~al.pdf). *R Journal* 2009 1/2
4. Strobl, Boulesteix, Kneib, Augustin, and Zeilis. [Conditional variable importance for random forests](http://www.biomedcentral.com/1471-2105/9/307). *BMC Bioinformatics* 2008, 9:307
5. Kuhn. [Building Predictive Models in R Using the caret Package](http://www.jstatsoft.org/v28/i05/paper). *JSS* 2008 28(5)


  [1]: http://edoc.ub.uni-muenchen.de/8904/1/Strobl_Carolin.pdf
  [2]: http://cran.r-project.org/web/packages/randomForest/index.html
  [3]: http://cran.r-project.org/web/packages/party/index.html
  [4]: http://caret.r-forge.r-project.org/Classification_and_Regression_Training.html
  [5]: http://www.redbrick.dcu.ie/~noel/R_classification.html
