## [When is *interactive* data visualization useful to use?](http://stats.stackexchange.com/questions/7048/when-is-interactive-data-visualization-useful-to-use)

In addition to linking quantitative or qualitative data to spatial patterns, as illustrated by @whuber, I would like to mention the use of EDA, with brushing and the various of linking plots together, for *longitudinal* and *high-dimensional* data analysis. 

Both are discussed in the excellent book, [*Interactive and Dynamic Graphics for Data Analysis With R and GGobi*][1], by Dianne Cook and Deborah F. Swayne (Springer UseR!, 2007), that you surely know. The authors have a nice discussion on EDA in Chapter 1, justifying the need for EDA to "force the unexpected upon us", quoting John Tukey (p. 13): The use of interactive and dynamic displays is neither [data snooping][2], nor preliminary data inspection (e.g., purely graphical summaries of the data), but it is merely seen as an interactive investigation of the data which might precede or complement pure hypothesis-based statistical modeling. 

Using GGobi together with its R interface ([rggobi][3]) also solves the problem of how to generate static graphics for intermediate report or final publication, even with [Projection Pursuit][4] (pp. 26-34), thanks to the [DescribeDisplay][5] or [ggplot2][6] packages.

In the same line, [Michael Friendly][7] has long advocated the use of data visualization in Categorical Data Analysis, which has been largely exemplified in the vcd package, but also in the more recent [vcdExtra][8] package (including dynamic viz. through the [rgl][9] package), which acts as a glue between the [vcd][10] and [gnm][11] packages for extending log-linear models. He recently gave a nice summary of that work during the [6th CARME][12] conference, [Advances in Visualizing Categorical Data Using the vcd, gnm and vcdExtra Packages in R][13].

Hence, EDA can also be thought of as providing a visual explanation of data (in the sense that it may account for unexpected patterns in the observed data), prior to a purely statistical modeling approach, *or* in parallel to it. That is, EDA not only provides useful ways for studying the internal structure of the data at hand, but it may also help to refine and/or summarize statistical models applied on it. It is in essence what [biplots][14] allow to do, for example. Although they are not multidimensional analysis techniques *per se*, they are tools for visualizing results from multidimensional analysis (by giving an *approximation* of the relationships when considering all individuals together, or all variables together, or both). Factor scores can be used in subsequent modeling in place of the original metric to either reduce the dimensionality or to provide intermediate levels of representation.

**Sidenote**

At risk of being old-fashionned, I'm still using `xlispstat` ([Luke Tierney][15]) from time to time. It has simple yet effective functionalities for interactive displays, currently not available in base R graphics. I'm not aware of similar capabilities in Clojure+Incanter (+Processing).


  [1]: http://www.ggobi.org/book/
  [2]: http://en.wikipedia.org/wiki/Data_dredging
  [3]: http://cran.r-project.org/web/packages/rggobi/index.html
  [4]: http://en.wikipedia.org/wiki/Projection_pursuit
  [5]: http://cran.r-project.org/web/packages/DescribeDisplay/index.html
  [6]: http://had.co.nz/ggplot2/
  [7]: http://www.datavis.ca/
  [8]: http://cran.r-project.org/web/packages/vcdExtra/index.html
  [9]: http://cran.r-project.org/web/packages/rgl/index.html
  [10]: http://cran.r-project.org/web/packages/vcd/index.html
  [11]: http://cran.r-project.org/web/packages/gnm/index.html
  [12]: http://carme2011.agrocampus-ouest.fr/
  [13]: http://www.datavis.ca/papers/adv-vcd-4up.pdf
  [14]: http://en.wikipedia.org/wiki/Biplot
  [15]: http://www.stat.uiowa.edu/~luke/
