## [How to visualize/summarize a matrix with number of rows ≫ number of columns?](http://stats.stackexchange.com/questions/8370/how-to-visualize-summarize-a-matrix-with-number-of-rows-gg-number-of-columns)

I was about to suggest something along @whuber's answer (I used this reordering technique but in a context of feature selection, so I was mainly concerned with the "variables view"). So let me suggest two other directions (but the first one is close to the already proposed one).

As far as **heatmaps** are concerned, you can display them after a slight rearrangement of rows (samples) and/or columns (genes) through hierarchical clustering (yet another aggregation method based on a (dis)similarity measure). There're a lot of R packages that can do this, for example the `cim()` function in [mixOmics][1]. Another package that might be of interest is [MADE4][2]; it relies on the very good [ade4][3] package for multivariate data analysis and visualization.

If you are concerned with the rather large number of variables, you might also consider some reduction method for **genes clustering**. One that I've heard about is *PCA-gene shaving* (Hastie et al., 2000), that is largely described in Izenman (2008). In essence, this is a two-stage iterative procedure where (a) for *feature selection*, we single out genes whose correlation with the first principal component is below a distribution-based threshold (say, the 10% of genes having the lowest correlation at each step), and (b) for *clustering*, we seek to maximize an $R^2$ measure (between-cluster/within-cluster variances) for $j$ successive clusters of size $k_j$, where the optimal $k_j$ is obtained by a permutation technique and the use of the *gap statistic* (after effects of the former cluster has been removed by residualization). More detailed informations can be found in the paper referenced below, but the general idea is to cluster genes into *small and potentially overlapping subsets of correlated genes that vary as much as possible across individuals*.


**References**

1. Hastie, T., Tibshirani, R., Eisen, M.B., Alzadeh, A., Levy, R., Staudt, L., Chan, W.C., Botstein, D., and Brown, P.O. (2000). ['Gene shaving' as a method for identifying distinct sets of genes with similar expression patterns][4]. *Genome Biology*, 1(2).
2. Izenman, A.J. (2008). *Modern Multivariate Statistical Techniques*. Springer.


  [1]: http://cran.r-project.org/web/packages/mixOmics/index.html
  [2]: http://www.bioinf.ucd.ie/people/aedin/R/
  [3]: http://cran.r-project.org/web/packages/ade4/index.html
  [4]: http://genomebiology.com/2000/1/2/research/0003/
