## [Problem with pvclust in R](http://stats.stackexchange.com/questions/9868/problem-with-pvclust-in-r)

It's difficult to answer without seeing the data itself, but my best guess is that you have some non numerical entries in the matrix/dataframe (which is what is expected by `pvclust`). For example, 

    > as.numeric(c(1,2,"NA"))
    [1]  1  2 NA

or 

    > dist(c(1,2,"NA"))
       1  2
    2  1   
    3 NA NA

will produce the same warning message ('*NAs introduced by coercion*'). I deliberately used `"NA"`, but any element that is not numerical will result in the same warning message.

So, 

1. A warning message is issued when trying to compute a distance matrix from the non-numerical input
2. Then, `hclust` failed when it is called within `pvclust`. Again, 

        > hclust(dist(c(1,2,"NA")))

  will throw the same error message.

In your first try, you called `hclust` by using a matrix. Can't you just check that you use the same variables in both cases, or that there is no strange values in your data (e.g., `summary(transpose)`), or no missing values coded as the character `"NA"` instead of `NA`, as below:

    > xx <- data.frame(replicate(3, sample(c(1,2,3), 3)))
    > xx[2,3] <- "NA"
    > is.na(xx[2,3])
    [1] FALSE
    > sapply(xx, is.character)
       X1    X2    X3 
    FALSE FALSE  TRUE 
    > apply(xx, 2, function(x) sum(is.na(x)))
    X1 X2 X3 
     0  0  0 
    # Now if we had a true NA value, we would see
    > xx[2,3] <- NA
    > apply(xx, 2, function(x) sum(is.na(x)))
    X1 X2 X3 
     0  0  1 

