## [Using LaTeX expression in gnuplot](http://stats.stackexchange.com/questions/10366/using-latex-expression-in-gnuplot)

If your penultimate goal is to embed your plot in a Latex document, you might consider using the [gnuplottex][1] package (as an alternative to [pgfplots][2] which is an awesome package). The idea is rather simple: you write your code chunk in your tex document directly (like you would do with Sweave), et voilà!

Here is an example (grabbed from gnuplot demos):

    \documentclass{standalone}
    \usepackage{gnuplottex}
    
    \begin{document}
    \begin{gnuplot}[scale=0.95, terminal=epslatex]
    set style fill transparent pattern 4 bo
    set style function filledcurves y1=0
    set clip two    
    Gauss(x,mu,sigma) = 1./(sigma*sqrt(2*pi)) * exp( -(x-mu)**2 / (2*sigma**2) )
    d1(x) = Gauss(x, 0.5, 0.5)
    d2(x) = Gauss(x,  2.,  1.)
    d3(x) = Gauss(x, -1.,  2.)
    set xrange [-5:5]
    set yrange [0:1]
    set xlabel "$\\bar x$ values"
    unset colorbox    
    plot d1(x) fs solid 1.0 lc rgb "forest-green", \
         d2(x) lc rgb "gold", d3(x) lc rgb "red"
    \end{gnuplot}
    \end{document}

You'll need to compile with the `-shell-escape` option to `pdflatex`.

![enter image description here][3]


  [1]: ftp://ftp.dante.de/tex-archive/help/Catalogue/entries/gnuplottex.html
  [2]: http://ctan.org/pkg/pgfplots
  [3]: http://i.stack.imgur.com/zhQyn.png
