## [How to add symbols on smooth lines in a R's lattice xyplot?](http://stats.stackexchange.com/questions/19210/how-to-add-symbols-on-smooth-lines-in-a-rs-lattice-xyplot)

Here is a way to achieve this:

    library(lattice)
    library(gridExtra)
    
    my.df <- data.frame(y=c(y1, y2, y3, z1, z2, z3), 
                        g=gl(6, 50), x=rep(x, 6))
    
    my.panel.loess <- function(x, y, span=2/3, ...) {
      loess.fit <- loess.smooth(x, y, span=span)
      panel.lines(loess.fit$x, loess.fit$y, ...)
    }
    
    pp <- list()
    pp[[1]] <- xyplot(y ~ x, data=my.df, groups=g, type="b", 
                      col=rep(c("blue","red"), each=3), cex=.6, 
                      panel=function(...) 
                        panel.superpose(panel.groups=my.panel.loess, ...))
    
    pp[[2]] <- update(pp[[1]], span=1/5)
    pp[[3]] <- update(pp[[1]], col=1:6, type=c("p", "g"))
    pp[[4]] <- update(pp[[1]], pch=rep(c(2,6), each=3))
    
    do.call(grid.arrange,  pp)

You will notice that I had to briefly define a custom panel function for the smoother. This is because I need to pass an extra parameter to `panel.lines` (`"p"`+`"l"`=`"b"`); note that it cannot be used directly when calling `panel.lines` since this formal parameter is already defined in `xyplot`.  

The rest of the code is pure drawing with varying parameters (all digested through the `...` argument). Although I arranged your data in a more convenient `data.frame`, I believe your original formulation will work with slight adaptation around the call to `panel.groups`.

![enter image description here][1]

However, you can annotate the curves directly with the [directlabels](http://cran.r-project.org/web/packages/directlabels/index.html) package (a lot of [examples](http://directlabels.r-forge.r-project.org/) are available on R-forge). Something along those lines should work fine:

    library(directlabels)
    pp0 <- xyplot(y ~ x, data=my.df, groups=g, type="smooth") 
    direct.label(pp0, "follow.points")

I should note that there is a nice function, `labcurve()`, in the [Hmisc](http://cran.r-project.org/web/packages/Hmisc/index.html) package that does pretty much the same job.
  [1]: http://i.stack.imgur.com/H9poh.png
