## [Possible extensions to the default diagnostic plots for lm (in R and in general)?](http://stats.stackexchange.com/questions/19227/possible-extensions-to-the-default-diagnostic-plots-for-lm-in-r-and-in-general)

This answer focus on what's available in base R, rather than external packages, although I agree that Fox's package is worth to adopt.

The function `influence()` (or its wrapper, `influence.measures()`) returns most of what we need for model diagnostic, including jacknifed statistics. As stated in Chambers and Hastie's *Statistical Models in S* (Wadsworth & Brooks, 1992), it can be used in combination to `summary.lm()`. One of the example provided in the so-called "white book" (pp. 130-131) allows to compute standardized (residuals with equal variance) and studentized (the same with a different estimate for SE) residuals, DFBETAS (change in the coefficients scaled by the SE for the regression coefficients), DFFIT (change in the fitted value when observation is dropped), and DFFITS (the same, with unit variance) measures without much difficulty. 

Based on your example, and defining the following objects:

    lms <- summary(fit)
    lmi <- influence(fit)
    e <- residuals(fit)
    s <- lms$sigma
    xxi <- diag(lms$cov.unscaled)
    si <- lmi$sigma
    h <- lmi$hat
    bi <- coef(fit) - coef(lmi)

we can compute the above quantities as follows:

    std. residuals    e / (s * (1-h)^.5
    stud. residuals   e / (si * (1-h)^.5
    dfbetas           bi / (si %o% xxi^.5 
    dffit             h * e / (1-h)
    dffits            h^.5 * e / (si * (1-h))

(This is *Table 4.1*, p. 131.)

Chambers and Hastie give the following S/R code for computing DFBETAS:

    dfbetas <- function(fit, lms = summary(fit), lmi = lm.influence(fit)) {
      xxi <- diag(lms$cov.unscaled)
      si <- lmi$sigma
      bi <- coef(fit) - coef(lmi)
      bi / (si %o% xxi^0.5)
    }

Why do I mention that approach? Because, first, I find this is interesting from a pedagogical perspective (that's what I am using when teaching introductory statistics courses) as it allows to illustrate what can be computed from the output of a fitted linear model fitted in R (but the same would apply with any other statistical package). Second, as the above quantities will be returned as simple vectors or matrices in R, that also means that we can choose the graphics device we want---lattice or ggplot--- to display those statistics, or use them to enhance an existing plot (e.g., highlight DFFITS values in a scatterplot by varying point size `cex`).


