The most commonly used **correlational approach** is called *multi-trait scaling* (MTS). The idea behind MTS is that items belonging to the same dimension are supposed to be more correlated to each other, as well as to their own scale, and that their correlations with items from other dimensions should be zero or at least of a lower magnitude. *Scaling success* then refers to the proportion of items having a larger correlation with their own dimension than with any other dimensions, with higher values indicating good convergent validity.
Basically, we compute interitem correlations within each scale and between scales; that is, for each subscale, every item score is correlated with every other item from the same subscale (convergent validity) and from other scales (divergent validity). Such a method is readily available in the [psy](http://cran.r-project.org/web/packages/psy/index.html) as `mtmm()`; it gives numerical results and graphical output when requested.

Some authors have suggested to examine one-tailed correlation tests, with appropriate correction for multiple comparisons (most of the times, a conservative approach like Bonferroni method). When assessing convergent validity, the usefulness of such tests might be discussed because the null hypothesis that is being considered is simply $H_0:\ \rho=0$ while we generally consider that a correlation of 0.3 (or 0.4) or above is indicative of a 'meaningful' correlation for two items belonging to the same subscale. This approach further allows to consider *scaling success with significance tests* as the number of significant correlations (i.e., only non-significant one-tailed correlation tests are counted as scaling errors). Finally, one generally report the average *homogeneity index* (within-scale interitem correlations) and an indicator of internal consistency like Cronbach's alpha. The above terminology comes from Fayers and Machin (2007). The `psy::mtmm()` function does not perform such tests, but it is not really hard to code.

Another approach relies on factor analytical methods, either exploratory or confirmatory **factor analysis** (CFA). In the CFA framework, the pattern matrix (correlations between items and factor, or loadings) of the hypothesized measurement model is specified in advance, whereas in exploratory factor analysis loadings, communalities and uniquenesses are estimated from the data without imposing constraints. 
Two critical points that are worth to remember are that (a) if the same sample is used to extract the factors (and construct scoring rules for each subscale) and assess goodness of fit of a factor model, then the generalizability of CFA findings will obviously be limited, and (b) if the model does not fit the data, nothing tell us what could be the correct model (even if so-called modification indices are used to refine the initial model, because in this case it is easy to fall into the trap of data snooping). In R, there are three packages that might be used: [sem](http://cran.r-project.org/web/packages/sem/index.html), [lavaan](http://lavaan.ugent.be/), [OpenMx](http://openmx.psyc.virginia.edu/). All three packages provide numerous example of CFA applications.

The following are rough guidelines for assessing model fit: a Comparative Fit (CFI) and Tucker-Lewis Index (TLI) greater than .90 are indicative of adequate model fit, with values near .95 being preferable; a Standardised Root Mean Square Residual (SRMR) below .10 (resp. .08) and a Root Mean Square Error of Approximation (RMSEA) below .08 (resp. .06) are indicative of acceptable (resp. good) model fit (Hu and Bentler, 1999). 

As a sidenote, I would recommend having a look at the [psych](http://cran.r-project.org/web/packages/psych/index.html) package as well. It features a lot of useful methods for psychometrics (item and reliability analysis, factor-related methods). William Revelle has a book in progress on [applied psychometrics with R](http://personality-project.org/r/book/). 

**References**

1. Fayers, P. M. and Machin, D. (2007). Quality of Life: The assessment, analysis and interpretation of patient-reported outcomes. Wiley.
2. Hu, L. T. and Bentler, P. M. (1999). Cutoff criteria for fit indexes in covariance structure analysis: Conventional criteria versus new alternatives. Structural Equation Modeling, 6, 1-55.
