## [How to get an R-squared for a loess fit?](http://stats.stackexchange.com/questions/24993/how-to-get-an-r-squared-for-a-loess-fit)

My first thought was to compute a [pseudo $R^2$](http://www.ats.ucla.edu/stat/mult_pkg/faq/general/psuedo_rsquareds.htm) measure as follows:

    ss.dist <- sum(scale(cars$dist, scale=FALSE)^2)
    ss.resid <- sum(resid(cars.lo)^2)
    1-ss.resid/ss.dist

Here, we get a value of 0.6814984 ($\approx$ `cor(cars$dist, predict(cars.lo))^2`), close to what would be obtained from a [GAM](http://en.wikipedia.org/wiki/Generalized_additive_model):

    library(mgcv)
    summary(gam(dist ~ speed, data=cars))

This also seems to be in agreement with what S `loess` function would return (I don't have S so I can't check by myself) as `Multiple R-squared`. For example, using the `airquality` R dataset, which looks like the `air` data Chambers and Hastie used in the 'white book' (the one that is being referenced in the on-line help for `loess`; but that's not the exact same dataset), I got an $R^2$ of 0.8101377 using the above formula. That's pretty in agreement with what Chambers and Hastie reported.

![enter image description here][1]

I should note that I didn't find any paper dealing specifically with that (ok, that was just a quick googling), and William Cleveland doesn't speak about $R^2$-like measure in [his paper](http://www.people.fas.harvard.edu/~gov2000/Handouts/lowess.pdf). 

However, I wonder if the liberty with which you can choose the degree of smoothing (or window `span`) does not preclude any use of $R^2$-based measure.


  [1]: http://i.stack.imgur.com/d5DVv.png
